/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwell.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwell *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwell_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwell_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwell_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwell();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwell::Heavy_vSwell(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_L8dD3HKA, &hTable_iLGtLBr2);
  numBytes += sTabread_init(&sTabread_EhICMUJ4, &hTable_iLGtLBr2, true);
  numBytes += sRPole_init(&sRPole_TjlummxT);
  numBytes += sEnv_init(&sEnv_rbwnx0XS, 1024, 512);
  numBytes += sLine_init(&sLine_RKHtBZzw);
  numBytes += cSlice_init(&cSlice_7YZBNG1H, 1, -1);
  numBytes += cSlice_init(&cSlice_UXvVCy8j, 1, -1);
  numBytes += cVar_init_f(&cVar_QHQjmSrv, 0.0f);
  numBytes += cIf_init(&cIf_QesvaK4s, false);
  numBytes += cBinop_init(&cBinop_JTRsIYtd, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_acOEpoMA, 1, -1);
  numBytes += cSlice_init(&cSlice_378QDliK, 1, -1);
  numBytes += cVar_init_f(&cVar_5xXYGDw0, 0.0f);
  numBytes += cIf_init(&cIf_YF08OxOR, false);
  numBytes += cBinop_init(&cBinop_oExARTdS, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_TWdlMQqt, 0.0f);
  numBytes += cVar_init_f(&cVar_aQv7wcYW, 0.0f);
  numBytes += cBinop_init(&cBinop_eBNIUmW6, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_A3jg9USY, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_n3B91UIr, 2, 1);
  numBytes += cSlice_init(&cSlice_OleYDJX2, 1, 1);
  numBytes += cSlice_init(&cSlice_AuWFz2oD, 0, 1);
  numBytes += cVar_init_f(&cVar_SpL4FHuH, 0.0f);
  numBytes += cIf_init(&cIf_s3bJQ48l, false);
  numBytes += cIf_init(&cIf_wZqn5xiD, false);
  numBytes += cIf_init(&cIf_ZSgN8eMi, false);
  numBytes += cIf_init(&cIf_RJrS43l3, false);
  numBytes += cIf_init(&cIf_GZxTakLw, false);
  numBytes += cBinop_init(&cBinop_z9pePvq1, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_ecz339Qm, 10.0f);
  numBytes += cPack_init(&cPack_A6HxBlev, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_eBRFGO3f, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_VJC1mE2Z, 10.0f);
  numBytes += cPack_init(&cPack_ygkG9DDk, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_kB9ADbh3, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_NXtXasX8, 10.0f);
  numBytes += cPack_init(&cPack_ahn3hbwg, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_5WKCzOcK, 1e-07f);
  numBytes += cIf_init(&cIf_B1isNzCw, true);
  numBytes += cVar_init_f(&cVar_xKDYjmUc, 1e-07f);
  numBytes += cVar_init_f(&cVar_qUqp6r8I, 1e-07f);
  numBytes += sVarf_init(&sVarf_fj0vY8Pv, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_SXmBDVD5, 0.0f);
  numBytes += cVar_init_f(&cVar_H00T1ICE, 20.0f);
  numBytes += cBinop_init(&cBinop_rUPWLolL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_NOiZFb7s, 0.0f);
  numBytes += cSlice_init(&cSlice_p8HT6ycD, 1, -1);
  numBytes += cSlice_init(&cSlice_RcUeX7GQ, 1, -1);
  numBytes += cVar_init_f(&cVar_yzJYtt0g, 0.0f);
  numBytes += cVar_init_f(&cVar_Rlg6iGMS, 20.0f);
  numBytes += cVar_init_f(&cVar_CJt2j2em, 0.0f);
  numBytes += cVar_init_f(&cVar_Ga3YuCjW, 0.0f);
  numBytes += cVar_init_f(&cVar_Lckm3e4q, 0.0f);
  numBytes += cSlice_init(&cSlice_h31jjzWh, 1, 1);
  numBytes += cSlice_init(&cSlice_AF217voD, 0, 1);
  numBytes += cBinop_init(&cBinop_QFahs049, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_a38H4e3y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0t51dhBD, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_D7sAkgfP, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_zl8dB8XQ, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_pQgiU6qE, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_mUwwiMiM, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_t2yiPNAM, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_IpOV1l31, 5.0f);
  numBytes += cVar_init_f(&cVar_XMCB0t6S, 500.0f);
  numBytes += cBinop_init(&cBinop_LxoWjhxE, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_sKAzEfgU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XGJ0lbru, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_4nlO3xGz, 0.0f);
  numBytes += cDelay_init(this, &cDelay_wKHMbgWs, 0.0f);
  numBytes += hTable_init(&hTable_iLGtLBr2, 256);
  numBytes += cTabhead_init(&cTabhead_bMQVZSGA, &hTable_iLGtLBr2);
  numBytes += cVar_init_s(&cVar_wIywsngM, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_xdnAsOXA, 8.0f);
  numBytes += cDelay_init(this, &cDelay_4k8S77UD, 0.0f);
  numBytes += cBinop_init(&cBinop_xaSvCIZf, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_8WPxzwxC, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_VE5uKiTt, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_57w7fxUn, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_93cqnb5Y, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_4U0ww5kT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Vdw0ieDK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w6Arwtta, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwell::~Heavy_vSwell() {
  sEnv_free(&sEnv_rbwnx0XS);
  cPack_free(&cPack_A6HxBlev);
  cPack_free(&cPack_ygkG9DDk);
  cPack_free(&cPack_ahn3hbwg);
  hTable_free(&hTable_iLGtLBr2);
}

HvTable *Heavy_vSwell::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_iLGtLBr2; // del-1001-swell
    default: return nullptr;
  }
}

void Heavy_vSwell::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qPO10Bw4_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BwVKVtsS_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fNm1f6eI_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AXghXyEi_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gaIYtblb_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iLEPzk2N_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_E7uqqyEZ_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jqmgewlB_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_I4Hzv3o7_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IhLJYIWY_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VH4agUGN_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7H2Ugd0x_sendMessage);
      break;
    }
    case 0xE7A7BB75: { // Trigger_by_Audio_ON
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VvrIwAjM_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dEZMybkK_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KYbWMeCg_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yKTbvw94_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TB2tXfuK_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwell::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 30.0f;
        info->maxVal = 85.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_by_Audio_ON";
        info->hash = 0xE7A7BB75;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 13;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwell::sEnv_rbwnx0XS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eBNIUmW6, HV_BINOP_GREATER_THAN, 0, m, &cBinop_eBNIUmW6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_A3jg9USY, HV_BINOP_LESS_THAN, 0, m, &cBinop_A3jg9USY_sendMessage);
}

void Heavy_vSwell::cSwitchcase_nG0ZTHyd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7YZBNG1H, 0, m, &cSlice_7YZBNG1H_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UXvVCy8j, 0, m, &cSlice_UXvVCy8j_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HB2qMpBr_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bEdBWlY5_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_7YZBNG1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_QHQjmSrv, 0, m, &cVar_QHQjmSrv_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_QHQjmSrv, 0, m, &cVar_QHQjmSrv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_UXvVCy8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JTRsIYtd, HV_BINOP_NEQ, 1, m, &cBinop_JTRsIYtd_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_QHQjmSrv, 1, m, &cVar_QHQjmSrv_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JTRsIYtd, HV_BINOP_NEQ, 1, m, &cBinop_JTRsIYtd_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_QHQjmSrv, 1, m, &cVar_QHQjmSrv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_QHQjmSrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bZYKyMrt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_QesvaK4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TAdWH4RD_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qJGFKbwf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_qJGFKbwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QHQjmSrv, 0, m, &cVar_QHQjmSrv_sendMessage);
}

void Heavy_vSwell::cCast_TAdWH4RD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JTRsIYtd, HV_BINOP_NEQ, 1, m, &cBinop_JTRsIYtd_sendMessage);
}

void Heavy_vSwell::cBinop_JTRsIYtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QesvaK4s, 1, m, &cIf_QesvaK4s_sendMessage);
}

void Heavy_vSwell::cCast_bEdBWlY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QesvaK4s, 0, m, &cIf_QesvaK4s_sendMessage);
}

void Heavy_vSwell::cCast_HB2qMpBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JTRsIYtd, HV_BINOP_NEQ, 0, m, &cBinop_JTRsIYtd_sendMessage);
}

void Heavy_vSwell::cSwitchcase_MoahKj3z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_acOEpoMA, 0, m, &cSlice_acOEpoMA_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_378QDliK, 0, m, &cSlice_378QDliK_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wv438DBx_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BozrDmYG_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_acOEpoMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_5xXYGDw0, 0, m, &cVar_5xXYGDw0_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_5xXYGDw0, 0, m, &cVar_5xXYGDw0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_378QDliK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_oExARTdS, HV_BINOP_NEQ, 1, m, &cBinop_oExARTdS_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_5xXYGDw0, 1, m, &cVar_5xXYGDw0_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_oExARTdS, HV_BINOP_NEQ, 1, m, &cBinop_oExARTdS_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_5xXYGDw0, 1, m, &cVar_5xXYGDw0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_5xXYGDw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_J7zWuBDl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_YF08OxOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3Rmz58U3_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_umhk9YmS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_3Rmz58U3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oExARTdS, HV_BINOP_NEQ, 1, m, &cBinop_oExARTdS_sendMessage);
}

void Heavy_vSwell::cCast_umhk9YmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5xXYGDw0, 0, m, &cVar_5xXYGDw0_sendMessage);
}

void Heavy_vSwell::cBinop_oExARTdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YF08OxOR, 1, m, &cIf_YF08OxOR_sendMessage);
}

void Heavy_vSwell::cCast_wv438DBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oExARTdS, HV_BINOP_NEQ, 0, m, &cBinop_oExARTdS_sendMessage);
}

void Heavy_vSwell::cCast_BozrDmYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YF08OxOR, 0, m, &cIf_YF08OxOR_sendMessage);
}

void Heavy_vSwell::cSwitchcase_bZYKyMrt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yj9PYYYC_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wyrHmVF2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_yj9PYYYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aQv7wcYW, 0, m, &cVar_aQv7wcYW_sendMessage);
}

void Heavy_vSwell::cCast_wyrHmVF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ymle9XHs_sendMessage(_c, 0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_B1isNzCw, 0, m, &cIf_B1isNzCw_sendMessage);
}

void Heavy_vSwell::cSwitchcase_J7zWuBDl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YGRzLPxN_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9xyD9H4R_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_YGRzLPxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TWdlMQqt, 0, m, &cVar_TWdlMQqt_sendMessage);
}

void Heavy_vSwell::cCast_9xyD9H4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_06VmCGqe_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_TWdlMQqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eBNIUmW6, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eBNIUmW6_sendMessage);
}

void Heavy_vSwell::cVar_aQv7wcYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A3jg9USY, HV_BINOP_LESS_THAN, 1, m, &cBinop_A3jg9USY_sendMessage);
}

void Heavy_vSwell::cBinop_eBNIUmW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nG0ZTHyd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_A3jg9USY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MoahKj3z_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_ymle9XHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eBNIUmW6, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eBNIUmW6_sendMessage);
}

void Heavy_vSwell::cMsg_06VmCGqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_A3jg9USY, HV_BINOP_LESS_THAN, 1, m, &cBinop_A3jg9USY_sendMessage);
}

void Heavy_vSwell::cSlice_n3B91UIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_DHDP7yd2_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_OleYDJX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_RJrS43l3, 0, m, &cIf_RJrS43l3_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_wZqn5xiD, 0, m, &cIf_wZqn5xiD_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_AuWFz2oD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_GZxTakLw, 0, m, &cIf_GZxTakLw_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_ZSgN8eMi, 0, m, &cIf_ZSgN8eMi_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_SpL4FHuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hsOro6Bc_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_s3bJQ48l, 0, m, &cIf_s3bJQ48l_sendMessage);
}

void Heavy_vSwell::cUnop_LCTWd48p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sQC1ISAp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_z9pePvq1, HV_BINOP_EQ, 1, m, &cBinop_z9pePvq1_sendMessage);
}

void Heavy_vSwell::cUnop_okJWuoKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sQC1ISAp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_z9pePvq1, HV_BINOP_EQ, 1, m, &cBinop_z9pePvq1_sendMessage);
}

void Heavy_vSwell::cIf_s3bJQ48l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_okJWuoKm_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_LCTWd48p_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_hsOro6Bc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s3bJQ48l, 1, m, &cIf_s3bJQ48l_sendMessage);
}

void Heavy_vSwell::cIf_wZqn5xiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WprCkqPQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_ZSgN8eMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_RJrS43l3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WprCkqPQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_GZxTakLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_DHDP7yd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z9pePvq1, HV_BINOP_EQ, 0, m, &cBinop_z9pePvq1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_ZzVZy8jQ_sendMessage);
}

void Heavy_vSwell::cBinop_sQC1ISAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DqbXodNt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f5nGIRM8_sendMessage);
}

void Heavy_vSwell::cBinop_z9pePvq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rvYQQ8ws_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DxG2u8yU_sendMessage);
}

void Heavy_vSwell::cCast_DxG2u8yU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GZxTakLw, 1, m, &cIf_GZxTakLw_sendMessage);
}

void Heavy_vSwell::cCast_rvYQQ8ws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wZqn5xiD, 1, m, &cIf_wZqn5xiD_sendMessage);
}

void Heavy_vSwell::cCast_f5nGIRM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZSgN8eMi, 1, m, &cIf_ZSgN8eMi_sendMessage);
}

void Heavy_vSwell::cCast_DqbXodNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RJrS43l3, 1, m, &cIf_RJrS43l3_sendMessage);
}

void Heavy_vSwell::cBinop_ZzVZy8jQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwell::cSwitchcase_IUtKIsv2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XG1VGCLr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XG1VGCLr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ecz339Qm, 1, m, &cDelay_ecz339Qm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QmP2hOPT_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_ecz339Qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ecz339Qm, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hPNsrwUD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V35O1Kx0_sendMessage);
  cSwitchcase_d9ROOQ9g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_XG1VGCLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ecz339Qm, 0, m, &cDelay_ecz339Qm_sendMessage);
}

void Heavy_vSwell::cCast_QmP2hOPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ecz339Qm, 0, m, &cDelay_ecz339Qm_sendMessage);
}

void Heavy_vSwell::cPack_A6HxBlev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WN2F0QL5_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_eBRFGO3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C5VxJECJ_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_DLhcA8xS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_IUtKIsv2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_GkRKCKHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_A6HxBlev, 0, m, &cPack_A6HxBlev_sendMessage);
}

void Heavy_vSwell::cCast_s7xsZnJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eBRFGO3f, 0, m, &cVar_eBRFGO3f_sendMessage);
}

void Heavy_vSwell::cMsg_C5VxJECJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_RKHtBZzw, 0, m, NULL);
}

void Heavy_vSwell::cMsg_WN2F0QL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_RKHtBZzw, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_d9ROOQ9g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QNjSZGSY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QNjSZGSY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VJC1mE2Z, 1, m, &cDelay_VJC1mE2Z_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i4pG9ppB_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_VJC1mE2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VJC1mE2Z, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZfcF5jc2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nAWFQ6OC_sendMessage);
  cSwitchcase_0CU7li40_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_QNjSZGSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VJC1mE2Z, 0, m, &cDelay_VJC1mE2Z_sendMessage);
}

void Heavy_vSwell::cCast_i4pG9ppB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VJC1mE2Z, 0, m, &cDelay_VJC1mE2Z_sendMessage);
}

void Heavy_vSwell::cPack_ygkG9DDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nGay7bVT_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_kB9ADbh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h5YzhA0r_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_VUgxo2BI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_d9ROOQ9g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_V35O1Kx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ygkG9DDk, 0, m, &cPack_ygkG9DDk_sendMessage);
}

void Heavy_vSwell::cCast_hPNsrwUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kB9ADbh3, 0, m, &cVar_kB9ADbh3_sendMessage);
}

void Heavy_vSwell::cMsg_h5YzhA0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_RKHtBZzw, 0, m, NULL);
}

void Heavy_vSwell::cMsg_nGay7bVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_RKHtBZzw, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_0CU7li40_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_I6hIcHi0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_I6hIcHi0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NXtXasX8, 1, m, &cDelay_NXtXasX8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tolf8ett_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_NXtXasX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NXtXasX8, m);
}

void Heavy_vSwell::cMsg_I6hIcHi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NXtXasX8, 0, m, &cDelay_NXtXasX8_sendMessage);
}

void Heavy_vSwell::cCast_tolf8ett_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NXtXasX8, 0, m, &cDelay_NXtXasX8_sendMessage);
}

void Heavy_vSwell::cPack_ahn3hbwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7zpiaFPf_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_5WKCzOcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cVe3oewb_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_plCWjbKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_0CU7li40_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_ZfcF5jc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5WKCzOcK, 0, m, &cVar_5WKCzOcK_sendMessage);
}

void Heavy_vSwell::cCast_nAWFQ6OC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ahn3hbwg, 0, m, &cPack_ahn3hbwg_sendMessage);
}

void Heavy_vSwell::cMsg_cVe3oewb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_RKHtBZzw, 0, m, NULL);
}

void Heavy_vSwell::cMsg_7zpiaFPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_RKHtBZzw, 0, m, NULL);
}

void Heavy_vSwell::cIf_B1isNzCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9ewzKT0o_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Is3D5mSY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSwitchcase_6TZHCd3X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s5iYR2kV_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_s5iYR2kV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9ewzKT0o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Is3D5mSY_sendMessage);
}

void Heavy_vSwell::cVar_xKDYjmUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5xwoBU03_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_qUqp6r8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ahn3hbwg, 1, m, &cPack_ahn3hbwg_sendMessage);
}

void Heavy_vSwell::cMsg_jIa1cjI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SrioBbwR_sendMessage);
}

void Heavy_vSwell::cSystem_SrioBbwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a38H4e3y, HV_BINOP_MULTIPLY, 1, m, &cBinop_a38H4e3y_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QFahs049, HV_BINOP_MULTIPLY, 1, m, &cBinop_QFahs049_sendMessage);
}

void Heavy_vSwell::cSwitchcase_hywPKrBe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_DlsusiPZ_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_DlsusiPZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oG19i2Ea_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_SXmBDVD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SXmBDVD5, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SXmBDVD5, 0, m, &cDelay_SXmBDVD5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NOiZFb7s, 0, m, &cVar_NOiZFb7s_sendMessage);
}

void Heavy_vSwell::cCast_oG19i2Ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DlsusiPZ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SXmBDVD5, 0, m, &cDelay_SXmBDVD5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NOiZFb7s, 0, m, &cVar_NOiZFb7s_sendMessage);
}

void Heavy_vSwell::cMsg_gQwHyju2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_a1kUFipk_sendMessage);
}

void Heavy_vSwell::cSystem_a1kUFipk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_q7dnXCtg_sendMessage);
}

void Heavy_vSwell::cVar_H00T1ICE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rUPWLolL, HV_BINOP_MULTIPLY, 0, m, &cBinop_rUPWLolL_sendMessage);
}

void Heavy_vSwell::cMsg_DlsusiPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SXmBDVD5, 0, m, &cDelay_SXmBDVD5_sendMessage);
}

void Heavy_vSwell::cBinop_XBtdwaW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SXmBDVD5, 2, m, &cDelay_SXmBDVD5_sendMessage);
}

void Heavy_vSwell::cBinop_q7dnXCtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rUPWLolL, HV_BINOP_MULTIPLY, 1, m, &cBinop_rUPWLolL_sendMessage);
}

void Heavy_vSwell::cBinop_rUPWLolL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_XBtdwaW2_sendMessage);
}

void Heavy_vSwell::cVar_NOiZFb7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0t51dhBD, HV_BINOP_SUBTRACT, 0, m, &cBinop_0t51dhBD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_v1VyhPAv_sendMessage);
}

void Heavy_vSwell::cSwitchcase_hxNxTDvt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NlJ49pJI_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ojOG6Tfn_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_NlJ49pJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Lckm3e4q, 0, m, &cVar_Lckm3e4q_sendMessage);
}

void Heavy_vSwell::cCast_ojOG6Tfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZTZUJW0L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UvKwtk6C_sendMessage);
}

void Heavy_vSwell::cSwitchcase_F2fliP4I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_p8HT6ycD, 0, m, &cSlice_p8HT6ycD_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RcUeX7GQ, 0, m, &cSlice_RcUeX7GQ_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5XlbCAi1_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_h31jjzWh, 0, m, &cSlice_h31jjzWh_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_AF217voD, 0, m, &cSlice_AF217voD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mYz6RP56_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Ag3VjkU_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_p8HT6ycD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_W2Fmw1Y5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_W2Fmw1Y5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_RcUeX7GQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wJCFz9Oq_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_swlkbHsA_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wJCFz9Oq_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_swlkbHsA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_yzJYtt0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vr9I5ih6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GMSz9pYa_sendMessage);
}

void Heavy_vSwell::cVar_Rlg6iGMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_myn4HkVc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_myn4HkVc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bG2IP10o_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_a38H4e3y, HV_BINOP_MULTIPLY, 0, m, &cBinop_a38H4e3y_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_zl8dB8XQ, HV_BINOP_DIVIDE, 1, m, &cBinop_zl8dB8XQ_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_H00T1ICE, 0, m, &cVar_H00T1ICE_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cCast_bG2IP10o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nuMXDC9U_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_CJt2j2em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t2yiPNAM, HV_BINOP_SUBTRACT, 1, m, &cBinop_t2yiPNAM_sendMessage);
}

void Heavy_vSwell::cVar_Ga3YuCjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Lckm3e4q, 0, m, &cVar_Lckm3e4q_sendMessage);
}

void Heavy_vSwell::cVar_Lckm3e4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D7sAkgfP, HV_BINOP_ADD, 0, m, &cBinop_D7sAkgfP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mUwwiMiM, HV_BINOP_ADD, 0, m, &cBinop_mUwwiMiM_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fj0vY8Pv, m);
}

void Heavy_vSwell::cSlice_h31jjzWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vr9I5ih6_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GMSz9pYa_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_AF217voD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zmUqbe6r_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C0geOHyT_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_yydq046E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NOiZFb7s, 1, m, &cVar_NOiZFb7s_sendMessage);
}

void Heavy_vSwell::cBinop_QFahs049_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yydq046E_sendMessage);
}

void Heavy_vSwell::cBinop_a38H4e3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rhLI1Uix_sendMessage);
}

void Heavy_vSwell::cBinop_rhLI1Uix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0t51dhBD, HV_BINOP_SUBTRACT, 1, m, &cBinop_0t51dhBD_sendMessage);
}

void Heavy_vSwell::cBinop_0t51dhBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NOiZFb7s, 1, m, &cVar_NOiZFb7s_sendMessage);
}

void Heavy_vSwell::cMsg_IoUFgZzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_hywPKrBe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_SQcmZxia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_hywPKrBe_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mUwwiMiM, HV_BINOP_ADD, 1, m, &cBinop_mUwwiMiM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_D7sAkgfP, HV_BINOP_ADD, 1, m, &cBinop_D7sAkgfP_sendMessage);
}

void Heavy_vSwell::cBinop_v1VyhPAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hxNxTDvt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_D7sAkgfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Lckm3e4q, 1, m, &cVar_Lckm3e4q_sendMessage);
}

void Heavy_vSwell::cBinop_zl8dB8XQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pQgiU6qE, HV_BINOP_DIVIDE, 1, m, &cBinop_pQgiU6qE_sendMessage);
}

void Heavy_vSwell::cBinop_pQgiU6qE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mUwwiMiM, HV_BINOP_ADD, 1, m, &cBinop_mUwwiMiM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_D7sAkgfP, HV_BINOP_ADD, 1, m, &cBinop_D7sAkgfP_sendMessage);
}

void Heavy_vSwell::cCast_GMSz9pYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zl8dB8XQ, HV_BINOP_DIVIDE, 0, m, &cBinop_zl8dB8XQ_sendMessage);
}

void Heavy_vSwell::cCast_vr9I5ih6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QFahs049, HV_BINOP_MULTIPLY, 0, m, &cBinop_QFahs049_sendMessage);
}

void Heavy_vSwell::cCast_zmUqbe6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ga3YuCjW, 1, m, &cVar_Ga3YuCjW_sendMessage);
}

void Heavy_vSwell::cCast_C0geOHyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t2yiPNAM, HV_BINOP_SUBTRACT, 0, m, &cBinop_t2yiPNAM_sendMessage);
}

void Heavy_vSwell::cCast_ZTZUJW0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SQcmZxia_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_UvKwtk6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ga3YuCjW, 0, m, &cVar_Ga3YuCjW_sendMessage);
}

void Heavy_vSwell::cBinop_mUwwiMiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CJt2j2em, 0, m, &cVar_CJt2j2em_sendMessage);
}

void Heavy_vSwell::cMsg_W2Fmw1Y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_hywPKrBe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_e2M5uhp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_yzJYtt0g, 1, m, &cVar_yzJYtt0g_sendMessage);
}

void Heavy_vSwell::cMsg_nuMXDC9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_a38H4e3y, HV_BINOP_MULTIPLY, 0, m, &cBinop_a38H4e3y_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zl8dB8XQ, HV_BINOP_DIVIDE, 1, m, &cBinop_zl8dB8XQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H00T1ICE, 0, m, &cVar_H00T1ICE_sendMessage);
}

void Heavy_vSwell::cCast_wJCFz9Oq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W2Fmw1Y5_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_swlkbHsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rH3IAshZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mUwwiMiM, HV_BINOP_ADD, 0, m, &cBinop_mUwwiMiM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Lckm3e4q, 1, m, &cVar_Lckm3e4q_sendMessage);
}

void Heavy_vSwell::cBinop_t2yiPNAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pQgiU6qE, HV_BINOP_DIVIDE, 0, m, &cBinop_pQgiU6qE_sendMessage);
}

void Heavy_vSwell::cCast_rH3IAshZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SQcmZxia_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_mYz6RP56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IoUFgZzP_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_5XlbCAi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yzJYtt0g, 0, m, &cVar_yzJYtt0g_sendMessage);
}

void Heavy_vSwell::cCast_5Ag3VjkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e2M5uhp0_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cSwitchcase_6U0XipKW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_S51Zf7zB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_S51Zf7zB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IpOV1l31, 1, m, &cDelay_IpOV1l31_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GfC0Nc45_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_IpOV1l31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IpOV1l31, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s7xsZnJj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GkRKCKHz_sendMessage);
  cSwitchcase_IUtKIsv2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_S51Zf7zB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IpOV1l31, 0, m, &cDelay_IpOV1l31_sendMessage);
}

void Heavy_vSwell::cCast_GfC0Nc45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IpOV1l31, 0, m, &cDelay_IpOV1l31_sendMessage);
}

void Heavy_vSwell::cVar_XMCB0t6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LxoWjhxE, HV_BINOP_MULTIPLY, 0, m, &cBinop_LxoWjhxE_sendMessage);
}

void Heavy_vSwell::cMsg_gllT4WZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_utL0JimK_sendMessage);
}

void Heavy_vSwell::cSystem_utL0JimK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aIYjbL24_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_LxoWjhxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_fzSBQXxU_sendMessage);
}

void Heavy_vSwell::cBinop_sJmllIc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LxoWjhxE, HV_BINOP_MULTIPLY, 1, m, &cBinop_LxoWjhxE_sendMessage);
}

void Heavy_vSwell::cMsg_aIYjbL24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sJmllIc3_sendMessage);
}

void Heavy_vSwell::cBinop_fzSBQXxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IWmdafqd_sendMessage);
}

void Heavy_vSwell::cBinop_IWmdafqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BYAHhtv2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XGJ0lbru, m);
}

void Heavy_vSwell::cBinop_BYAHhtv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sKAzEfgU, m);
}

void Heavy_vSwell::cMsg_ehpcO6am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_p9vR84AN_sendMessage);
}

void Heavy_vSwell::cSystem_p9vR84AN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_U2HUQsC4_sendMessage);
}

void Heavy_vSwell::cDelay_4nlO3xGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4nlO3xGz, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wKHMbgWs, 0, m, &cDelay_wKHMbgWs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4nlO3xGz, 0, m, &cDelay_4nlO3xGz_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_L8dD3HKA, 1, m, NULL);
}

void Heavy_vSwell::cDelay_wKHMbgWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wKHMbgWs, m);
  cMsg_N3O3jQV5_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cSwitchcase_SnWInOHA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_MmqPc67m_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cBinop_XOplKRPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y1b6gDX7_sendMessage(_c, 0, m);
}

void Heavy_vSwell::hTable_iLGtLBr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3xW3yq49_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4nlO3xGz, 2, m, &cDelay_4nlO3xGz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3lL4LsVB_sendMessage);
}

void Heavy_vSwell::cMsg_Y1b6gDX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_iLGtLBr2, 0, m, &hTable_iLGtLBr2_sendMessage);
}

void Heavy_vSwell::cBinop_U2HUQsC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_XOplKRPc_sendMessage);
}

void Heavy_vSwell::cMsg_N3O3jQV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_iLGtLBr2, 0, m, &hTable_iLGtLBr2_sendMessage);
}

void Heavy_vSwell::cCast_3lL4LsVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4nlO3xGz, 0, m, &cDelay_4nlO3xGz_sendMessage);
}

void Heavy_vSwell::cMsg_3xW3yq49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_wKHMbgWs, 2, m, &cDelay_wKHMbgWs_sendMessage);
}

void Heavy_vSwell::cMsg_MmqPc67m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_L8dD3HKA, 1, m, NULL);
}

void Heavy_vSwell::cTabhead_bMQVZSGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8WPxzwxC, HV_BINOP_SUBTRACT, 0, m, &cBinop_8WPxzwxC_sendMessage);
}

void Heavy_vSwell::cMsg_kNlwmjVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_J2hB87cH_sendMessage);
}

void Heavy_vSwell::cSystem_J2hB87cH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_aJfXO8uP_sendMessage);
}

void Heavy_vSwell::cVar_wIywsngM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LqOY44bF_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cDelay_xdnAsOXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xdnAsOXA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4k8S77UD, 0, m, &cDelay_4k8S77UD_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EhICMUJ4, 0, m, &sTabread_EhICMUJ4_sendMessage);
}

void Heavy_vSwell::cDelay_4k8S77UD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4k8S77UD, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EhICMUJ4, 0, m, &sTabread_EhICMUJ4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4k8S77UD, 0, m, &cDelay_4k8S77UD_sendMessage);
}

void Heavy_vSwell::sTabread_EhICMUJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_57w7fxUn, HV_BINOP_SUBTRACT, 0, m, &cBinop_57w7fxUn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_xaSvCIZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VE5uKiTt, HV_BINOP_MAX, 0, m, &cBinop_VE5uKiTt_sendMessage);
}

void Heavy_vSwell::cBinop_aJfXO8uP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xaSvCIZf, HV_BINOP_MULTIPLY, 0, m, &cBinop_xaSvCIZf_sendMessage);
}

void Heavy_vSwell::cBinop_8WPxzwxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0xdLto9k_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EhICMUJ4, 0, m, &sTabread_EhICMUJ4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MNRqTE6M_sendMessage);
}

void Heavy_vSwell::cSystem_354AklgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_57w7fxUn, HV_BINOP_SUBTRACT, 1, m, &cBinop_57w7fxUn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4k8S77UD, 2, m, &cDelay_4k8S77UD_sendMessage);
}

void Heavy_vSwell::cMsg_LqOY44bF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_354AklgQ_sendMessage);
}

void Heavy_vSwell::cMsg_0xdLto9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xdnAsOXA, 0, m, &cDelay_xdnAsOXA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4k8S77UD, 0, m, &cDelay_4k8S77UD_sendMessage);
}

void Heavy_vSwell::cMsg_pCZgUyDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_VE5uKiTt, HV_BINOP_MAX, 1, m, &cBinop_VE5uKiTt_sendMessage);
}

void Heavy_vSwell::cBinop_VE5uKiTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8WPxzwxC, HV_BINOP_SUBTRACT, 1, m, &cBinop_8WPxzwxC_sendMessage);
}

void Heavy_vSwell::cCast_MNRqTE6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xdnAsOXA, 0, m, &cDelay_xdnAsOXA_sendMessage);
}

void Heavy_vSwell::cBinop_78Nv2Osl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xdnAsOXA, 2, m, &cDelay_xdnAsOXA_sendMessage);
}

void Heavy_vSwell::cBinop_57w7fxUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_78Nv2Osl_sendMessage);
}

void Heavy_vSwell::cCast_J4osTRVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wIywsngM, 0, m, &cVar_wIywsngM_sendMessage);
  cMsg_kNlwmjVt_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_bMQVZSGA, 0, m, &cTabhead_bMQVZSGA_sendMessage);
}

void Heavy_vSwell::cUnop_fdqXSFZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Vdw0ieDK, m);
}

void Heavy_vSwell::cCast_9ewzKT0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uAkAG7jx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xKDYjmUc, 0, m, &cVar_xKDYjmUc_sendMessage);
}

void Heavy_vSwell::cCast_Is3D5mSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6U0XipKW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_1IAqSx9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TWdlMQqt, 0, m, &cVar_TWdlMQqt_sendMessage);
}

void Heavy_vSwell::cCast_U2yAKf8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_93cqnb5Y, HV_BINOP_SUBTRACT, 0, m, &cBinop_93cqnb5Y_sendMessage);
}

void Heavy_vSwell::cBinop_93cqnb5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aQv7wcYW, 0, m, &cVar_aQv7wcYW_sendMessage);
}

void Heavy_vSwell::cSend_uAkAG7jx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yKTbvw94_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_WprCkqPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6TZHCd3X_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_ri14vKf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_F2fliP4I_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_5xwoBU03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RKHtBZzw, 0, m, NULL);
}

void Heavy_vSwell::cSend_nYcznsuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TB2tXfuK_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_HqR0KtS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IpOV1l31, 1, m, &cDelay_IpOV1l31_sendMessage);
}

void Heavy_vSwell::cBinop_P4MlBviZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_fdqXSFZC_sendMessage);
}

void Heavy_vSwell::cReceive_I4Hzv3o7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_93cqnb5Y, HV_BINOP_SUBTRACT, 1, m, &cBinop_93cqnb5Y_sendMessage);
}

void Heavy_vSwell::cReceive_dEZMybkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gQwHyju2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_H00T1ICE, 0, m, &cVar_H00T1ICE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SpL4FHuH, 0, m, &cVar_SpL4FHuH_sendMessage);
  cMsg_jIa1cjI2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CJt2j2em, 0, m, &cVar_CJt2j2em_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Rlg6iGMS, 0, m, &cVar_Rlg6iGMS_sendMessage);
  cMsg_gllT4WZK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XMCB0t6S, 0, m, &cVar_XMCB0t6S_sendMessage);
  cMsg_ehpcO6am_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qUqp6r8I, 0, m, &cVar_qUqp6r8I_sendMessage);
  cMsg_pCZgUyDj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wIywsngM, 0, m, &cVar_wIywsngM_sendMessage);
  cMsg_kNlwmjVt_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_bMQVZSGA, 0, m, &cTabhead_bMQVZSGA_sendMessage);
}

void Heavy_vSwell::cReceive_KYbWMeCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_n3B91UIr, 0, m, &cSlice_n3B91UIr_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_OleYDJX2, 0, m, &cSlice_OleYDJX2_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_AuWFz2oD, 0, m, &cSlice_AuWFz2oD_sendMessage);
}

void Heavy_vSwell::cReceive_iLEPzk2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4U0ww5kT, m);
}

void Heavy_vSwell::cReceive_yKTbvw94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DLhcA8xS_sendMessage(_c, 0, m);
  cMsg_VUgxo2BI_sendMessage(_c, 0, m);
  cMsg_plCWjbKv_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_jqmgewlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U2yAKf8c_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1IAqSx9I_sendMessage);
}

void Heavy_vSwell::cReceive_7H2Ugd0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9ewzKT0o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Is3D5mSY_sendMessage);
}

void Heavy_vSwell::cReceive_VvrIwAjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B1isNzCw, 1, m, &cIf_B1isNzCw_sendMessage);
}

void Heavy_vSwell::cReceive_qPO10Bw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kB9ADbh3, 1, m, &cVar_kB9ADbh3_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_A6HxBlev, 1, m, &cPack_A6HxBlev_sendMessage);
}

void Heavy_vSwell::cReceive_BwVKVtsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_A6HxBlev, 2, m, &cPack_A6HxBlev_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ecz339Qm, 1, m, &cDelay_ecz339Qm_sendMessage);
}

void Heavy_vSwell::cReceive_fNm1f6eI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ygkG9DDk, 1, m, &cPack_ygkG9DDk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5WKCzOcK, 1, m, &cVar_5WKCzOcK_sendMessage);
}

void Heavy_vSwell::cReceive_AXghXyEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ygkG9DDk, 2, m, &cPack_ygkG9DDk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VJC1mE2Z, 1, m, &cDelay_VJC1mE2Z_sendMessage);
}

void Heavy_vSwell::cReceive_gaIYtblb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ahn3hbwg, 2, m, &cPack_ahn3hbwg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NXtXasX8, 1, m, &cDelay_NXtXasX8_sendMessage);
}

void Heavy_vSwell::cReceive_TB2tXfuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qUqp6r8I, 1, m, &cVar_qUqp6r8I_sendMessage);
  cMsg_ri14vKf7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xKDYjmUc, 1, m, &cVar_xKDYjmUc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eBRFGO3f, 1, m, &cVar_eBRFGO3f_sendMessage);
}

void Heavy_vSwell::cReceive_E7uqqyEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nYcznsuG_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_VH4agUGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_HqR0KtS3_sendMessage);
}

void Heavy_vSwell::cReceive_IhLJYIWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_P4MlBviZ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_w6Arwtta, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwell::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4;

  // input and output vars
  hv_bufferf_t O0;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_L8dD3HKA, VIf(I0));
    __hv_tabread_f(&sTabread_EhICMUJ4, VOf(Bf0));
    __hv_varread_f(&sVarf_XGJ0lbru, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_sKAzEfgU, VOf(Bf2));
    __hv_rpole_f(&sRPole_TjlummxT, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_w6Arwtta, VOf(Bf1));
    __hv_varread_f(&sVarf_Vdw0ieDK, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf3));
    __hv_gt_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_sqrt_f(VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_rbwnx0XS, VIf(Bf3), &sEnv_rbwnx0XS_sendMessage);
    __hv_line_f(&sLine_RKHtBZzw, VOf(Bf3));
    __hv_varread_f(&sVarf_4U0ww5kT, VOf(Bf1));
    __hv_pow_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_fj0vY8Pv, VOf(Bf3));
    __hv_max_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwell::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 1 channel(s)
  float **const bOut = &outputBuffers;

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwell::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 1 channel(s)
  float *const bOut = outputBuffers;

  int n = processInline(bIn, bOut, n4);

  

  return n;
}
