/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELL_HPP_
#define _HEAVY_CONTEXT_VSWELL_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalTabread.h"
#include "HvSignalRPole.h"
#include "HvControlSlice.h"
#include "HvSignalEnvelope.h"
#include "HvControlBinop.h"
#include "HvSignalLine.h"
#include "HvControlTabhead.h"
#include "HvControlDelay.h"
#include "HvTable.h"
#include "HvControlSystem.h"
#include "HvControlUnop.h"
#include "HvMath.h"
#include "HvSignalTabwrite.h"
#include "HvControlVar.h"
#include "HvControlCast.h"
#include "HvControlIf.h"
#include "HvControlPack.h"
#include "HvSignalDel1.h"
#include "HvSignalVar.h"

class Heavy_vSwell : public HeavyContext {

 public:
  Heavy_vSwell(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwell();

  const char *getName() override { return "vSwell"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 1; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_BY_AUDIO_ON = 0xE7A7BB75, // Trigger_by_Audio_ON
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_rbwnx0XS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_nG0ZTHyd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7YZBNG1H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_UXvVCy8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QHQjmSrv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QesvaK4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qJGFKbwf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TAdWH4RD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JTRsIYtd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bEdBWlY5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HB2qMpBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MoahKj3z_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_acOEpoMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_378QDliK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5xXYGDw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YF08OxOR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3Rmz58U3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_umhk9YmS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oExARTdS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wv438DBx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BozrDmYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bZYKyMrt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_yj9PYYYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wyrHmVF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_J7zWuBDl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_YGRzLPxN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9xyD9H4R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TWdlMQqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aQv7wcYW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eBNIUmW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A3jg9USY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ymle9XHs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_06VmCGqe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_n3B91UIr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_OleYDJX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_AuWFz2oD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SpL4FHuH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LCTWd48p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_okJWuoKm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_s3bJQ48l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hsOro6Bc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wZqn5xiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZSgN8eMi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RJrS43l3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GZxTakLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DHDP7yd2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sQC1ISAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z9pePvq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DxG2u8yU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rvYQQ8ws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f5nGIRM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DqbXodNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZzVZy8jQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IUtKIsv2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ecz339Qm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XG1VGCLr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QmP2hOPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_A6HxBlev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eBRFGO3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DLhcA8xS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GkRKCKHz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s7xsZnJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C5VxJECJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WN2F0QL5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_d9ROOQ9g_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_VJC1mE2Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QNjSZGSY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i4pG9ppB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_ygkG9DDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kB9ADbh3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VUgxo2BI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V35O1Kx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hPNsrwUD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h5YzhA0r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nGay7bVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0CU7li40_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_NXtXasX8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I6hIcHi0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tolf8ett_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_ahn3hbwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5WKCzOcK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_plCWjbKv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZfcF5jc2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nAWFQ6OC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cVe3oewb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7zpiaFPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_B1isNzCw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6TZHCd3X_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_s5iYR2kV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xKDYjmUc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qUqp6r8I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jIa1cjI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SrioBbwR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hywPKrBe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_SXmBDVD5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oG19i2Ea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gQwHyju2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_a1kUFipk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H00T1ICE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DlsusiPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XBtdwaW2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q7dnXCtg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rUPWLolL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NOiZFb7s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hxNxTDvt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_NlJ49pJI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ojOG6Tfn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_F2fliP4I_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_p8HT6ycD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_RcUeX7GQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yzJYtt0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Rlg6iGMS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_myn4HkVc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_bG2IP10o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CJt2j2em_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ga3YuCjW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Lckm3e4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_h31jjzWh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_AF217voD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yydq046E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QFahs049_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a38H4e3y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rhLI1Uix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0t51dhBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IoUFgZzP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SQcmZxia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v1VyhPAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D7sAkgfP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zl8dB8XQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pQgiU6qE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GMSz9pYa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vr9I5ih6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zmUqbe6r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C0geOHyT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZTZUJW0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UvKwtk6C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mUwwiMiM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W2Fmw1Y5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e2M5uhp0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nuMXDC9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wJCFz9Oq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_swlkbHsA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t2yiPNAM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rH3IAshZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mYz6RP56_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5XlbCAi1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Ag3VjkU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6U0XipKW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_IpOV1l31_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S51Zf7zB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GfC0Nc45_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XMCB0t6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gllT4WZK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_utL0JimK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LxoWjhxE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sJmllIc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aIYjbL24_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fzSBQXxU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IWmdafqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BYAHhtv2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ehpcO6am_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_p9vR84AN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4nlO3xGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wKHMbgWs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SnWInOHA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_XOplKRPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_iLGtLBr2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y1b6gDX7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U2HUQsC4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N3O3jQV5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3lL4LsVB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3xW3yq49_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MmqPc67m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_bMQVZSGA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kNlwmjVt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_J2hB87cH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wIywsngM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xdnAsOXA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4k8S77UD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_EhICMUJ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xaSvCIZf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aJfXO8uP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8WPxzwxC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_354AklgQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LqOY44bF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0xdLto9k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pCZgUyDj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VE5uKiTt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MNRqTE6M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_78Nv2Osl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_57w7fxUn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J4osTRVc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_fdqXSFZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9ewzKT0o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Is3D5mSY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1IAqSx9I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U2yAKf8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_93cqnb5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_uAkAG7jx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WprCkqPQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ri14vKf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5xwoBU03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nYcznsuG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HqR0KtS3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P4MlBviZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_I4Hzv3o7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dEZMybkK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KYbWMeCg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iLEPzk2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yKTbvw94_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jqmgewlB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7H2Ugd0x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VvrIwAjM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qPO10Bw4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BwVKVtsS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fNm1f6eI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AXghXyEi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gaIYtblb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TB2tXfuK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_E7uqqyEZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VH4agUGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IhLJYIWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_L8dD3HKA;
  SignalTabread sTabread_EhICMUJ4;
  SignalRPole sRPole_TjlummxT;
  SignalEnvelope sEnv_rbwnx0XS;
  SignalLine sLine_RKHtBZzw;
  ControlSlice cSlice_7YZBNG1H;
  ControlSlice cSlice_UXvVCy8j;
  ControlVar cVar_QHQjmSrv;
  ControlIf cIf_QesvaK4s;
  ControlBinop cBinop_JTRsIYtd;
  ControlSlice cSlice_acOEpoMA;
  ControlSlice cSlice_378QDliK;
  ControlVar cVar_5xXYGDw0;
  ControlIf cIf_YF08OxOR;
  ControlBinop cBinop_oExARTdS;
  ControlVar cVar_TWdlMQqt;
  ControlVar cVar_aQv7wcYW;
  ControlBinop cBinop_eBNIUmW6;
  ControlBinop cBinop_A3jg9USY;
  ControlSlice cSlice_n3B91UIr;
  ControlSlice cSlice_OleYDJX2;
  ControlSlice cSlice_AuWFz2oD;
  ControlVar cVar_SpL4FHuH;
  ControlIf cIf_s3bJQ48l;
  ControlBinop cBinop_hsOro6Bc;
  ControlIf cIf_wZqn5xiD;
  ControlIf cIf_ZSgN8eMi;
  ControlIf cIf_RJrS43l3;
  ControlIf cIf_GZxTakLw;
  ControlBinop cBinop_DHDP7yd2;
  ControlBinop cBinop_sQC1ISAp;
  ControlBinop cBinop_z9pePvq1;
  ControlBinop cBinop_ZzVZy8jQ;
  ControlDelay cDelay_ecz339Qm;
  ControlPack cPack_A6HxBlev;
  ControlVar cVar_eBRFGO3f;
  ControlDelay cDelay_VJC1mE2Z;
  ControlPack cPack_ygkG9DDk;
  ControlVar cVar_kB9ADbh3;
  ControlDelay cDelay_NXtXasX8;
  ControlPack cPack_ahn3hbwg;
  ControlVar cVar_5WKCzOcK;
  ControlIf cIf_B1isNzCw;
  ControlVar cVar_xKDYjmUc;
  ControlVar cVar_qUqp6r8I;
  SignalVarf sVarf_fj0vY8Pv;
  ControlDelay cDelay_SXmBDVD5;
  ControlVar cVar_H00T1ICE;
  ControlBinop cBinop_XBtdwaW2;
  ControlBinop cBinop_q7dnXCtg;
  ControlBinop cBinop_rUPWLolL;
  ControlVar cVar_NOiZFb7s;
  ControlSlice cSlice_p8HT6ycD;
  ControlSlice cSlice_RcUeX7GQ;
  ControlVar cVar_yzJYtt0g;
  ControlVar cVar_Rlg6iGMS;
  ControlVar cVar_CJt2j2em;
  ControlVar cVar_Ga3YuCjW;
  ControlVar cVar_Lckm3e4q;
  ControlSlice cSlice_h31jjzWh;
  ControlSlice cSlice_AF217voD;
  ControlBinop cBinop_yydq046E;
  ControlBinop cBinop_QFahs049;
  ControlBinop cBinop_a38H4e3y;
  ControlBinop cBinop_rhLI1Uix;
  ControlBinop cBinop_0t51dhBD;
  ControlBinop cBinop_v1VyhPAv;
  ControlBinop cBinop_D7sAkgfP;
  ControlBinop cBinop_zl8dB8XQ;
  ControlBinop cBinop_pQgiU6qE;
  ControlBinop cBinop_mUwwiMiM;
  ControlBinop cBinop_t2yiPNAM;
  ControlDelay cDelay_IpOV1l31;
  ControlVar cVar_XMCB0t6S;
  ControlBinop cBinop_LxoWjhxE;
  ControlBinop cBinop_sJmllIc3;
  SignalVarf sVarf_sKAzEfgU;
  ControlBinop cBinop_fzSBQXxU;
  ControlBinop cBinop_IWmdafqd;
  ControlBinop cBinop_BYAHhtv2;
  SignalVarf sVarf_XGJ0lbru;
  ControlDelay cDelay_4nlO3xGz;
  ControlDelay cDelay_wKHMbgWs;
  ControlBinop cBinop_XOplKRPc;
  HvTable hTable_iLGtLBr2;
  ControlBinop cBinop_U2HUQsC4;
  ControlTabhead cTabhead_bMQVZSGA;
  ControlVar cVar_wIywsngM;
  ControlDelay cDelay_xdnAsOXA;
  ControlDelay cDelay_4k8S77UD;
  ControlBinop cBinop_xaSvCIZf;
  ControlBinop cBinop_aJfXO8uP;
  ControlBinop cBinop_8WPxzwxC;
  ControlBinop cBinop_VE5uKiTt;
  ControlBinop cBinop_78Nv2Osl;
  ControlBinop cBinop_57w7fxUn;
  ControlBinop cBinop_93cqnb5Y;
  ControlBinop cBinop_WprCkqPQ;
  ControlBinop cBinop_HqR0KtS3;
  ControlBinop cBinop_P4MlBviZ;
  SignalVarf sVarf_4U0ww5kT;
  SignalVarf sVarf_Vdw0ieDK;
  SignalVarf sVarf_w6Arwtta;
};

#endif // _HEAVY_CONTEXT_VSWELL_HPP_
