/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwellST.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwellST *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwellST_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwellST_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwellST_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwellST();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwellST::Heavy_vSwellST(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_hy9TJuS8, &hTable_VZzn4z2F);
  numBytes += sTabwrite_init(&sTabwrite_0toLXfpI, &hTable_8LryHeNT);
  numBytes += sRPole_init(&sRPole_YqQ5ha2g);
  numBytes += sEnv_init(&sEnv_nqlvq9FN, 1024, 512);
  numBytes += sTabread_init(&sTabread_7kCKzuAo, &hTable_VZzn4z2F, true);
  numBytes += sLine_init(&sLine_GvNBBC7F);
  numBytes += sTabread_init(&sTabread_d12ZHMpe, &hTable_8LryHeNT, true);
  numBytes += cSlice_init(&cSlice_4DGd3bLN, 1, -1);
  numBytes += cSlice_init(&cSlice_ac52hSIW, 1, -1);
  numBytes += cVar_init_f(&cVar_9koZ9BLq, 0.0f);
  numBytes += cIf_init(&cIf_pdFZ28u9, false);
  numBytes += cBinop_init(&cBinop_gpFarSej, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_3MhVo779, 1, -1);
  numBytes += cSlice_init(&cSlice_PWfyJ12Y, 1, -1);
  numBytes += cVar_init_f(&cVar_FMappCnp, 0.0f);
  numBytes += cIf_init(&cIf_r5MNJvg8, false);
  numBytes += cBinop_init(&cBinop_IWE3l8ge, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_Ld6bzfP4, 0.0f);
  numBytes += cVar_init_f(&cVar_GkEdu07u, 0.0f);
  numBytes += cBinop_init(&cBinop_dqQPisdB, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_r4zmp1r9, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_881SsyaW, 2, 1);
  numBytes += cSlice_init(&cSlice_60eUC78H, 1, 1);
  numBytes += cSlice_init(&cSlice_DpWXQmXR, 0, 1);
  numBytes += cVar_init_f(&cVar_S5DjZ7LF, 0.0f);
  numBytes += cIf_init(&cIf_qKbDFiHZ, false);
  numBytes += cIf_init(&cIf_uIQTIFkM, false);
  numBytes += cIf_init(&cIf_huKz1rQq, false);
  numBytes += cIf_init(&cIf_DWfLFmI8, false);
  numBytes += cIf_init(&cIf_cPazxhjj, false);
  numBytes += cBinop_init(&cBinop_qlvqjYQ9, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_1gnBBkzI, 10.0f);
  numBytes += cPack_init(&cPack_JXzkq9MC, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_LyjpKlYA, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_3LstDT3N, 10.0f);
  numBytes += cPack_init(&cPack_cqQ8rSYb, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_GyRoetmD, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_fWVjpr0O, 10.0f);
  numBytes += cPack_init(&cPack_ljdwIdIJ, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_ZQ8SMt0T, 1e-07f);
  numBytes += cVar_init_f(&cVar_DsOForl5, 1e-07f);
  numBytes += cVar_init_f(&cVar_TDSeM11Z, 1e-07f);
  numBytes += sVarf_init(&sVarf_6dsdIqoV, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_gGgxtt1J, 0.0f);
  numBytes += cVar_init_f(&cVar_dGcAKYRA, 20.0f);
  numBytes += cBinop_init(&cBinop_qLG4tkem, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_qSf5lowp, 0.0f);
  numBytes += cSlice_init(&cSlice_qns21Lat, 1, -1);
  numBytes += cSlice_init(&cSlice_hzEsZduQ, 1, -1);
  numBytes += cVar_init_f(&cVar_UfyAGMl2, 0.0f);
  numBytes += cVar_init_f(&cVar_ftVVpmKO, 20.0f);
  numBytes += cVar_init_f(&cVar_yUsDMSqy, 0.0f);
  numBytes += cVar_init_f(&cVar_NW4kR9hh, 0.0f);
  numBytes += cVar_init_f(&cVar_pB9hsVrj, 0.0f);
  numBytes += cSlice_init(&cSlice_yysuwTM6, 1, 1);
  numBytes += cSlice_init(&cSlice_23BkLja2, 0, 1);
  numBytes += cBinop_init(&cBinop_HtwUlMUs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nFwJHSqo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_35bEzmD3, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_xhytQYyu, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_jHQV4Y2y, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_LGAuQb3K, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_5fcilwLL, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Gu5SNM82, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_P2HSrcKf, 5.0f);
  numBytes += cVar_init_f(&cVar_ydvEw7hk, 500.0f);
  numBytes += cBinop_init(&cBinop_eoWSU6aL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_M3Z4tAtc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_s2s9xTcN, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_xSpkpq0m, 0.0f);
  numBytes += cDelay_init(this, &cDelay_al949VxR, 0.0f);
  numBytes += hTable_init(&hTable_VZzn4z2F, 256);
  numBytes += cTabhead_init(&cTabhead_IeSVGKoI, &hTable_VZzn4z2F);
  numBytes += cVar_init_s(&cVar_byMp6y9Z, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_xrhXAPWK, 8.0f);
  numBytes += cDelay_init(this, &cDelay_xMTK5cgP, 0.0f);
  numBytes += cBinop_init(&cBinop_R5cHqMcr, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_uboKcJ7M, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_8zNhYo3S, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_8uQwmKgV, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_QgU0MFLs, 0.0f);
  numBytes += cDelay_init(this, &cDelay_HBpy6owW, 0.0f);
  numBytes += hTable_init(&hTable_8LryHeNT, 256);
  numBytes += cTabhead_init(&cTabhead_3TR4BgVr, &hTable_8LryHeNT);
  numBytes += cVar_init_s(&cVar_nduK5Pqr, "del-1001-swell2");
  numBytes += cDelay_init(this, &cDelay_L4hZXnwF, 8.0f);
  numBytes += cDelay_init(this, &cDelay_P5uyY4Rs, 0.0f);
  numBytes += cBinop_init(&cBinop_nZjtGhjp, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_Pzdhd4Y8, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_q9PxQsR0, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_MwCWOmEj, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_WeEWtGIt, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_OnhVmdtd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lVWFb5pn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lSoIt2mZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zvzZpsvQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1EDuTxTx, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwellST::~Heavy_vSwellST() {
  sEnv_free(&sEnv_nqlvq9FN);
  cPack_free(&cPack_JXzkq9MC);
  cPack_free(&cPack_cqQ8rSYb);
  cPack_free(&cPack_ljdwIdIJ);
  hTable_free(&hTable_VZzn4z2F);
  hTable_free(&hTable_8LryHeNT);
}

HvTable *Heavy_vSwellST::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_VZzn4z2F; // del-1001-swell
    case 0x505A9C79: return &hTable_8LryHeNT; // del-1001-swell2
    default: return nullptr;
  }
}

void Heavy_vSwellST::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mitEVHYh_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O1AhwBwc_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FgI3tZE7_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CkGUprmu_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jHCgAO8e_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5k5eanEq_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dOwXahEv_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dMLQns5P_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l605ZcFa_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1bTJVzSg_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AXYq3ieg_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7Hfx54UK_sendMessage);
      break;
    }
    case 0x4E6E7C40: { // Trigger_Left
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FJySCXiO_sendMessage);
      break;
    }
    case 0xB181ABB6: { // Trigger_Right
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NAkMMQyH_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vmhYgwKA_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kqoMHusN_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qCnKzMVu_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aumLI9Hr_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwellST::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 20.0f;
        info->maxVal = 90.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_Left";
        info->hash = 0x4E6E7C40;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "Trigger_Right";
        info->hash = 0xB181ABB6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 14;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwellST::sEnv_nqlvq9FN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dqQPisdB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_dqQPisdB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_r4zmp1r9, HV_BINOP_LESS_THAN, 0, m, &cBinop_r4zmp1r9_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_C6FfUjD4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4DGd3bLN, 0, m, &cSlice_4DGd3bLN_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ac52hSIW, 0, m, &cSlice_ac52hSIW_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3XsOj038_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qf2hLinY_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_4DGd3bLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_9koZ9BLq, 0, m, &cVar_9koZ9BLq_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_9koZ9BLq, 0, m, &cVar_9koZ9BLq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_ac52hSIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_gpFarSej, HV_BINOP_NEQ, 1, m, &cBinop_gpFarSej_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_9koZ9BLq, 1, m, &cVar_9koZ9BLq_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_gpFarSej, HV_BINOP_NEQ, 1, m, &cBinop_gpFarSej_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_9koZ9BLq, 1, m, &cVar_9koZ9BLq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_9koZ9BLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FFtip57j_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_pdFZ28u9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9ebnCfA6_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oE6ncd19_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_oE6ncd19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9koZ9BLq, 0, m, &cVar_9koZ9BLq_sendMessage);
}

void Heavy_vSwellST::cCast_9ebnCfA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gpFarSej, HV_BINOP_NEQ, 1, m, &cBinop_gpFarSej_sendMessage);
}

void Heavy_vSwellST::cBinop_gpFarSej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pdFZ28u9, 1, m, &cIf_pdFZ28u9_sendMessage);
}

void Heavy_vSwellST::cCast_Qf2hLinY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pdFZ28u9, 0, m, &cIf_pdFZ28u9_sendMessage);
}

void Heavy_vSwellST::cCast_3XsOj038_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gpFarSej, HV_BINOP_NEQ, 0, m, &cBinop_gpFarSej_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_ChdZ0aRA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3MhVo779, 0, m, &cSlice_3MhVo779_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PWfyJ12Y, 0, m, &cSlice_PWfyJ12Y_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HUGcmdkt_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fE1fetkH_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_3MhVo779_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_FMappCnp, 0, m, &cVar_FMappCnp_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_FMappCnp, 0, m, &cVar_FMappCnp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_PWfyJ12Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_IWE3l8ge, HV_BINOP_NEQ, 1, m, &cBinop_IWE3l8ge_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_FMappCnp, 1, m, &cVar_FMappCnp_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_IWE3l8ge, HV_BINOP_NEQ, 1, m, &cBinop_IWE3l8ge_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_FMappCnp, 1, m, &cVar_FMappCnp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_FMappCnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9r1M817I_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_r5MNJvg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F0ufk5zl_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hyLrSRL6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_hyLrSRL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FMappCnp, 0, m, &cVar_FMappCnp_sendMessage);
}

void Heavy_vSwellST::cCast_F0ufk5zl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IWE3l8ge, HV_BINOP_NEQ, 1, m, &cBinop_IWE3l8ge_sendMessage);
}

void Heavy_vSwellST::cBinop_IWE3l8ge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r5MNJvg8, 1, m, &cIf_r5MNJvg8_sendMessage);
}

void Heavy_vSwellST::cCast_HUGcmdkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IWE3l8ge, HV_BINOP_NEQ, 0, m, &cBinop_IWE3l8ge_sendMessage);
}

void Heavy_vSwellST::cCast_fE1fetkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r5MNJvg8, 0, m, &cIf_r5MNJvg8_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_FFtip57j_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6G64nXq6_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HLi79mmi_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_6G64nXq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GkEdu07u, 0, m, &cVar_GkEdu07u_sendMessage);
}

void Heavy_vSwellST::cCast_HLi79mmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VRcQxIW4_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9FXJc0KH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GJaMkxYo_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_9r1M817I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cXvV57co_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RltJ4yJR_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_cXvV57co_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ld6bzfP4, 0, m, &cVar_Ld6bzfP4_sendMessage);
}

void Heavy_vSwellST::cCast_RltJ4yJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rpf0vwTk_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_Ld6bzfP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dqQPisdB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_dqQPisdB_sendMessage);
}

void Heavy_vSwellST::cVar_GkEdu07u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r4zmp1r9, HV_BINOP_LESS_THAN, 1, m, &cBinop_r4zmp1r9_sendMessage);
}

void Heavy_vSwellST::cBinop_dqQPisdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_C6FfUjD4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_r4zmp1r9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ChdZ0aRA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_VRcQxIW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dqQPisdB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_dqQPisdB_sendMessage);
}

void Heavy_vSwellST::cMsg_Rpf0vwTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_r4zmp1r9, HV_BINOP_LESS_THAN, 1, m, &cBinop_r4zmp1r9_sendMessage);
}

void Heavy_vSwellST::cSlice_881SsyaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oUMUysLa_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_60eUC78H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_DWfLFmI8, 0, m, &cIf_DWfLFmI8_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_uIQTIFkM, 0, m, &cIf_uIQTIFkM_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_DpWXQmXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_cPazxhjj, 0, m, &cIf_cPazxhjj_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_huKz1rQq, 0, m, &cIf_huKz1rQq_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_S5DjZ7LF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bGAu71On_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qKbDFiHZ, 0, m, &cIf_qKbDFiHZ_sendMessage);
}

void Heavy_vSwellST::cUnop_5VsSc7kx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CAJd2ubI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qlvqjYQ9, HV_BINOP_EQ, 1, m, &cBinop_qlvqjYQ9_sendMessage);
}

void Heavy_vSwellST::cUnop_UgZMykTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CAJd2ubI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qlvqjYQ9, HV_BINOP_EQ, 1, m, &cBinop_qlvqjYQ9_sendMessage);
}

void Heavy_vSwellST::cIf_qKbDFiHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_UgZMykTF_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_5VsSc7kx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_bGAu71On_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qKbDFiHZ, 1, m, &cIf_qKbDFiHZ_sendMessage);
}

void Heavy_vSwellST::cIf_uIQTIFkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_253HqiY9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_huKz1rQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_DWfLFmI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_253HqiY9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_cPazxhjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_oUMUysLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qlvqjYQ9, HV_BINOP_EQ, 0, m, &cBinop_qlvqjYQ9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_5Nk49TqG_sendMessage);
}

void Heavy_vSwellST::cBinop_CAJd2ubI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X5wJgo0w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lKWmAFf5_sendMessage);
}

void Heavy_vSwellST::cBinop_qlvqjYQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GPvl5jh5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tPbHRXKL_sendMessage);
}

void Heavy_vSwellST::cCast_GPvl5jh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uIQTIFkM, 1, m, &cIf_uIQTIFkM_sendMessage);
}

void Heavy_vSwellST::cCast_tPbHRXKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cPazxhjj, 1, m, &cIf_cPazxhjj_sendMessage);
}

void Heavy_vSwellST::cCast_lKWmAFf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_huKz1rQq, 1, m, &cIf_huKz1rQq_sendMessage);
}

void Heavy_vSwellST::cCast_X5wJgo0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DWfLFmI8, 1, m, &cIf_DWfLFmI8_sendMessage);
}

void Heavy_vSwellST::cBinop_5Nk49TqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwellST::cSwitchcase_Cxsv7brM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_70zn9EEX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_70zn9EEX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1gnBBkzI, 1, m, &cDelay_1gnBBkzI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dTVhBCgK_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_1gnBBkzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1gnBBkzI, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8jSENLS5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tHuGtW3B_sendMessage);
  cSwitchcase_PdSPjrub_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_70zn9EEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1gnBBkzI, 0, m, &cDelay_1gnBBkzI_sendMessage);
}

void Heavy_vSwellST::cCast_dTVhBCgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1gnBBkzI, 0, m, &cDelay_1gnBBkzI_sendMessage);
}

void Heavy_vSwellST::cPack_JXzkq9MC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rnsy0y6q_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_LyjpKlYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BCsVTyf1_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_JeJecZ1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_Cxsv7brM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_RiMCR7js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LyjpKlYA, 0, m, &cVar_LyjpKlYA_sendMessage);
}

void Heavy_vSwellST::cCast_BfDSm7Km_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_JXzkq9MC, 0, m, &cPack_JXzkq9MC_sendMessage);
}

void Heavy_vSwellST::cMsg_BCsVTyf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_GvNBBC7F, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_Rnsy0y6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_GvNBBC7F, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_PdSPjrub_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FU2gL818_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FU2gL818_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_3LstDT3N, 1, m, &cDelay_3LstDT3N_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s9YFqObx_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_3LstDT3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3LstDT3N, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XW8aKLkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cvCRud9X_sendMessage);
  cSwitchcase_OvnwElXT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_FU2gL818_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3LstDT3N, 0, m, &cDelay_3LstDT3N_sendMessage);
}

void Heavy_vSwellST::cCast_s9YFqObx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3LstDT3N, 0, m, &cDelay_3LstDT3N_sendMessage);
}

void Heavy_vSwellST::cPack_cqQ8rSYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_64OdJIDp_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_GyRoetmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0W7L1HJp_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_bydyvYGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_PdSPjrub_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_tHuGtW3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_cqQ8rSYb, 0, m, &cPack_cqQ8rSYb_sendMessage);
}

void Heavy_vSwellST::cCast_8jSENLS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GyRoetmD, 0, m, &cVar_GyRoetmD_sendMessage);
}

void Heavy_vSwellST::cMsg_0W7L1HJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_GvNBBC7F, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_64OdJIDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_GvNBBC7F, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_OvnwElXT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kp1N3XT0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kp1N3XT0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fWVjpr0O, 1, m, &cDelay_fWVjpr0O_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bqfuYeA0_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_fWVjpr0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fWVjpr0O, m);
}

void Heavy_vSwellST::cMsg_kp1N3XT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fWVjpr0O, 0, m, &cDelay_fWVjpr0O_sendMessage);
}

void Heavy_vSwellST::cCast_bqfuYeA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fWVjpr0O, 0, m, &cDelay_fWVjpr0O_sendMessage);
}

void Heavy_vSwellST::cPack_ljdwIdIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kOx5uRkg_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_ZQ8SMt0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sg6HBWPP_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_feVF1ZNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_OvnwElXT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_cvCRud9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ljdwIdIJ, 0, m, &cPack_ljdwIdIJ_sendMessage);
}

void Heavy_vSwellST::cCast_XW8aKLkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZQ8SMt0T, 0, m, &cVar_ZQ8SMt0T_sendMessage);
}

void Heavy_vSwellST::cMsg_sg6HBWPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_GvNBBC7F, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_kOx5uRkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_GvNBBC7F, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_qXcNfUBV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UdeqecdW_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_UdeqecdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9FXJc0KH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GJaMkxYo_sendMessage);
}

void Heavy_vSwellST::cVar_DsOForl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SKddBQPo_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_TDSeM11Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ljdwIdIJ, 1, m, &cPack_ljdwIdIJ_sendMessage);
}

void Heavy_vSwellST::cMsg_8whTkin8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XtuAID0L_sendMessage);
}

void Heavy_vSwellST::cSystem_XtuAID0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nFwJHSqo, HV_BINOP_MULTIPLY, 1, m, &cBinop_nFwJHSqo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HtwUlMUs, HV_BINOP_MULTIPLY, 1, m, &cBinop_HtwUlMUs_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_xVRnJhz8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_125F00Pq_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_125F00Pq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lcbtdqhp_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_gGgxtt1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gGgxtt1J, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gGgxtt1J, 0, m, &cDelay_gGgxtt1J_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qSf5lowp, 0, m, &cVar_qSf5lowp_sendMessage);
}

void Heavy_vSwellST::cCast_Lcbtdqhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_125F00Pq_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gGgxtt1J, 0, m, &cDelay_gGgxtt1J_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qSf5lowp, 0, m, &cVar_qSf5lowp_sendMessage);
}

void Heavy_vSwellST::cMsg_8lTCvPdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dluaA8CX_sendMessage);
}

void Heavy_vSwellST::cSystem_dluaA8CX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4YLAayB2_sendMessage);
}

void Heavy_vSwellST::cVar_dGcAKYRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qLG4tkem, HV_BINOP_MULTIPLY, 0, m, &cBinop_qLG4tkem_sendMessage);
}

void Heavy_vSwellST::cMsg_125F00Pq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gGgxtt1J, 0, m, &cDelay_gGgxtt1J_sendMessage);
}

void Heavy_vSwellST::cBinop_ENcFjRSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gGgxtt1J, 2, m, &cDelay_gGgxtt1J_sendMessage);
}

void Heavy_vSwellST::cBinop_4YLAayB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qLG4tkem, HV_BINOP_MULTIPLY, 1, m, &cBinop_qLG4tkem_sendMessage);
}

void Heavy_vSwellST::cBinop_qLG4tkem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_ENcFjRSU_sendMessage);
}

void Heavy_vSwellST::cVar_qSf5lowp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_35bEzmD3, HV_BINOP_SUBTRACT, 0, m, &cBinop_35bEzmD3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_RO9Z36gh_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_hmdWhTzy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OtYlj9Yf_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N1ItsnXU_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_OtYlj9Yf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pB9hsVrj, 0, m, &cVar_pB9hsVrj_sendMessage);
}

void Heavy_vSwellST::cCast_N1ItsnXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TUqoeK6H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MBojWiek_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_Mbdj5Tpm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qns21Lat, 0, m, &cSlice_qns21Lat_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hzEsZduQ, 0, m, &cSlice_hzEsZduQ_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pJQRvcPg_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_yysuwTM6, 0, m, &cSlice_yysuwTM6_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_23BkLja2, 0, m, &cSlice_23BkLja2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WH8lE1uj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kwz6T4D5_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_qns21Lat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_YMJ2Z7Rq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_YMJ2Z7Rq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_hzEsZduQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_trsuConz_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dpsAwBW6_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_trsuConz_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dpsAwBW6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_UfyAGMl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SLHaXazG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GwWIkRw0_sendMessage);
}

void Heavy_vSwellST::cVar_ftVVpmKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Y9ggSu8u_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_Y9ggSu8u_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3POKzccF_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_nFwJHSqo, HV_BINOP_MULTIPLY, 0, m, &cBinop_nFwJHSqo_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_jHQV4Y2y, HV_BINOP_DIVIDE, 1, m, &cBinop_jHQV4Y2y_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_dGcAKYRA, 0, m, &cVar_dGcAKYRA_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cCast_3POKzccF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CZ8KGSwD_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_yUsDMSqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gu5SNM82, HV_BINOP_SUBTRACT, 1, m, &cBinop_Gu5SNM82_sendMessage);
}

void Heavy_vSwellST::cVar_NW4kR9hh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pB9hsVrj, 0, m, &cVar_pB9hsVrj_sendMessage);
}

void Heavy_vSwellST::cVar_pB9hsVrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xhytQYyu, HV_BINOP_ADD, 0, m, &cBinop_xhytQYyu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5fcilwLL, HV_BINOP_ADD, 0, m, &cBinop_5fcilwLL_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6dsdIqoV, m);
}

void Heavy_vSwellST::cSlice_yysuwTM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SLHaXazG_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GwWIkRw0_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_23BkLja2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rLS0t84a_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kP3ba99c_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_ecx9lexx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qSf5lowp, 1, m, &cVar_qSf5lowp_sendMessage);
}

void Heavy_vSwellST::cBinop_HtwUlMUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ecx9lexx_sendMessage);
}

void Heavy_vSwellST::cBinop_nFwJHSqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0xTikT6I_sendMessage);
}

void Heavy_vSwellST::cBinop_0xTikT6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_35bEzmD3, HV_BINOP_SUBTRACT, 1, m, &cBinop_35bEzmD3_sendMessage);
}

void Heavy_vSwellST::cBinop_35bEzmD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qSf5lowp, 1, m, &cVar_qSf5lowp_sendMessage);
}

void Heavy_vSwellST::cMsg_VioxPyiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_xVRnJhz8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_hOqxs0KE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_xVRnJhz8_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5fcilwLL, HV_BINOP_ADD, 1, m, &cBinop_5fcilwLL_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xhytQYyu, HV_BINOP_ADD, 1, m, &cBinop_xhytQYyu_sendMessage);
}

void Heavy_vSwellST::cBinop_RO9Z36gh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hmdWhTzy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_xhytQYyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pB9hsVrj, 1, m, &cVar_pB9hsVrj_sendMessage);
}

void Heavy_vSwellST::cBinop_jHQV4Y2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LGAuQb3K, HV_BINOP_DIVIDE, 1, m, &cBinop_LGAuQb3K_sendMessage);
}

void Heavy_vSwellST::cBinop_LGAuQb3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5fcilwLL, HV_BINOP_ADD, 1, m, &cBinop_5fcilwLL_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xhytQYyu, HV_BINOP_ADD, 1, m, &cBinop_xhytQYyu_sendMessage);
}

void Heavy_vSwellST::cCast_GwWIkRw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jHQV4Y2y, HV_BINOP_DIVIDE, 0, m, &cBinop_jHQV4Y2y_sendMessage);
}

void Heavy_vSwellST::cCast_SLHaXazG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HtwUlMUs, HV_BINOP_MULTIPLY, 0, m, &cBinop_HtwUlMUs_sendMessage);
}

void Heavy_vSwellST::cCast_kP3ba99c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gu5SNM82, HV_BINOP_SUBTRACT, 0, m, &cBinop_Gu5SNM82_sendMessage);
}

void Heavy_vSwellST::cCast_rLS0t84a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NW4kR9hh, 1, m, &cVar_NW4kR9hh_sendMessage);
}

void Heavy_vSwellST::cCast_TUqoeK6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hOqxs0KE_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_MBojWiek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NW4kR9hh, 0, m, &cVar_NW4kR9hh_sendMessage);
}

void Heavy_vSwellST::cBinop_5fcilwLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yUsDMSqy, 0, m, &cVar_yUsDMSqy_sendMessage);
}

void Heavy_vSwellST::cMsg_YMJ2Z7Rq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_xVRnJhz8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_gZxNhsiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_UfyAGMl2, 1, m, &cVar_UfyAGMl2_sendMessage);
}

void Heavy_vSwellST::cMsg_CZ8KGSwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nFwJHSqo, HV_BINOP_MULTIPLY, 0, m, &cBinop_nFwJHSqo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jHQV4Y2y, HV_BINOP_DIVIDE, 1, m, &cBinop_jHQV4Y2y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dGcAKYRA, 0, m, &cVar_dGcAKYRA_sendMessage);
}

void Heavy_vSwellST::cCast_dpsAwBW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nrpHSbaH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5fcilwLL, HV_BINOP_ADD, 0, m, &cBinop_5fcilwLL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pB9hsVrj, 1, m, &cVar_pB9hsVrj_sendMessage);
}

void Heavy_vSwellST::cCast_trsuConz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YMJ2Z7Rq_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_Gu5SNM82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LGAuQb3K, HV_BINOP_DIVIDE, 0, m, &cBinop_LGAuQb3K_sendMessage);
}

void Heavy_vSwellST::cCast_nrpHSbaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hOqxs0KE_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_Kwz6T4D5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gZxNhsiZ_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_pJQRvcPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UfyAGMl2, 0, m, &cVar_UfyAGMl2_sendMessage);
}

void Heavy_vSwellST::cCast_WH8lE1uj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VioxPyiH_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_hncAhn6B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6DZstFjA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6DZstFjA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_P2HSrcKf, 1, m, &cDelay_P2HSrcKf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1oHv8XUY_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_P2HSrcKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_P2HSrcKf, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RiMCR7js_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BfDSm7Km_sendMessage);
  cSwitchcase_Cxsv7brM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_6DZstFjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_P2HSrcKf, 0, m, &cDelay_P2HSrcKf_sendMessage);
}

void Heavy_vSwellST::cCast_1oHv8XUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_P2HSrcKf, 0, m, &cDelay_P2HSrcKf_sendMessage);
}

void Heavy_vSwellST::cVar_ydvEw7hk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eoWSU6aL, HV_BINOP_MULTIPLY, 0, m, &cBinop_eoWSU6aL_sendMessage);
}

void Heavy_vSwellST::cMsg_P0kHd4LE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QLoGBq4z_sendMessage);
}

void Heavy_vSwellST::cSystem_QLoGBq4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aCWLGLSP_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_eoWSU6aL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_M6HrrpUi_sendMessage);
}

void Heavy_vSwellST::cBinop_ZV8Hyzdx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eoWSU6aL, HV_BINOP_MULTIPLY, 1, m, &cBinop_eoWSU6aL_sendMessage);
}

void Heavy_vSwellST::cMsg_aCWLGLSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZV8Hyzdx_sendMessage);
}

void Heavy_vSwellST::cBinop_M6HrrpUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mUJcx25p_sendMessage);
}

void Heavy_vSwellST::cBinop_mUJcx25p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_T5ukpMfN_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_s2s9xTcN, m);
}

void Heavy_vSwellST::cBinop_T5ukpMfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_M3Z4tAtc, m);
}

void Heavy_vSwellST::cMsg_A69Y9jyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sqX9SUNE_sendMessage);
}

void Heavy_vSwellST::cSystem_sqX9SUNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_sJ7J0KI3_sendMessage);
}

void Heavy_vSwellST::cDelay_xSpkpq0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xSpkpq0m, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_al949VxR, 0, m, &cDelay_al949VxR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xSpkpq0m, 0, m, &cDelay_xSpkpq0m_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hy9TJuS8, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_al949VxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_al949VxR, m);
  cMsg_4qs31hft_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_rfSnxNQn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_nGwbJwzx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_gePfmA0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LqzQKMIp_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_VZzn4z2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_45DsOuCn_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xSpkpq0m, 2, m, &cDelay_xSpkpq0m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DfSNWrmZ_sendMessage);
}

void Heavy_vSwellST::cMsg_LqzQKMIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_VZzn4z2F, 0, m, &hTable_VZzn4z2F_sendMessage);
}

void Heavy_vSwellST::cBinop_sJ7J0KI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_gePfmA0r_sendMessage);
}

void Heavy_vSwellST::cMsg_4qs31hft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_VZzn4z2F, 0, m, &hTable_VZzn4z2F_sendMessage);
}

void Heavy_vSwellST::cCast_DfSNWrmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xSpkpq0m, 0, m, &cDelay_xSpkpq0m_sendMessage);
}

void Heavy_vSwellST::cMsg_45DsOuCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_al949VxR, 2, m, &cDelay_al949VxR_sendMessage);
}

void Heavy_vSwellST::cMsg_nGwbJwzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hy9TJuS8, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_IeSVGKoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uboKcJ7M, HV_BINOP_SUBTRACT, 0, m, &cBinop_uboKcJ7M_sendMessage);
}

void Heavy_vSwellST::cMsg_rL6TxPGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GaTkC1yl_sendMessage);
}

void Heavy_vSwellST::cSystem_GaTkC1yl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0X2hekze_sendMessage);
}

void Heavy_vSwellST::cVar_byMp6y9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w6Gy8VrM_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_xrhXAPWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xrhXAPWK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xMTK5cgP, 0, m, &cDelay_xMTK5cgP_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7kCKzuAo, 0, m, &sTabread_7kCKzuAo_sendMessage);
}

void Heavy_vSwellST::cDelay_xMTK5cgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xMTK5cgP, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7kCKzuAo, 0, m, &sTabread_7kCKzuAo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xMTK5cgP, 0, m, &cDelay_xMTK5cgP_sendMessage);
}

void Heavy_vSwellST::sTabread_7kCKzuAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_8uQwmKgV, HV_BINOP_SUBTRACT, 0, m, &cBinop_8uQwmKgV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_R5cHqMcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8zNhYo3S, HV_BINOP_MAX, 0, m, &cBinop_8zNhYo3S_sendMessage);
}

void Heavy_vSwellST::cBinop_0X2hekze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R5cHqMcr, HV_BINOP_MULTIPLY, 0, m, &cBinop_R5cHqMcr_sendMessage);
}

void Heavy_vSwellST::cBinop_uboKcJ7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V5kVjNmi_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7kCKzuAo, 0, m, &sTabread_7kCKzuAo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C2CVdbwE_sendMessage);
}

void Heavy_vSwellST::cSystem_dTAfuG4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8uQwmKgV, HV_BINOP_SUBTRACT, 1, m, &cBinop_8uQwmKgV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xMTK5cgP, 2, m, &cDelay_xMTK5cgP_sendMessage);
}

void Heavy_vSwellST::cMsg_w6Gy8VrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dTAfuG4Z_sendMessage);
}

void Heavy_vSwellST::cMsg_V5kVjNmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xrhXAPWK, 0, m, &cDelay_xrhXAPWK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xMTK5cgP, 0, m, &cDelay_xMTK5cgP_sendMessage);
}

void Heavy_vSwellST::cMsg_t0yTNwRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_8zNhYo3S, HV_BINOP_MAX, 1, m, &cBinop_8zNhYo3S_sendMessage);
}

void Heavy_vSwellST::cBinop_8zNhYo3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uboKcJ7M, HV_BINOP_SUBTRACT, 1, m, &cBinop_uboKcJ7M_sendMessage);
}

void Heavy_vSwellST::cCast_C2CVdbwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xrhXAPWK, 0, m, &cDelay_xrhXAPWK_sendMessage);
}

void Heavy_vSwellST::cBinop_UzyhSwv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xrhXAPWK, 2, m, &cDelay_xrhXAPWK_sendMessage);
}

void Heavy_vSwellST::cBinop_8uQwmKgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UzyhSwv9_sendMessage);
}

void Heavy_vSwellST::cCast_4gOXY6c7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_byMp6y9Z, 0, m, &cVar_byMp6y9Z_sendMessage);
  cMsg_rL6TxPGd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IeSVGKoI, 0, m, &cTabhead_IeSVGKoI_sendMessage);
}

void Heavy_vSwellST::cMsg_ueswJ3h0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JTjqhyv7_sendMessage);
}

void Heavy_vSwellST::cSystem_JTjqhyv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gGIQqQ0i_sendMessage);
}

void Heavy_vSwellST::cDelay_QgU0MFLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QgU0MFLs, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HBpy6owW, 0, m, &cDelay_HBpy6owW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QgU0MFLs, 0, m, &cDelay_QgU0MFLs_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_0toLXfpI, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_HBpy6owW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HBpy6owW, m);
  cMsg_zY0ODnRL_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_G0cc0cN9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_LHEzXoRP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_URa0IfaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G3s1ISG9_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_8LryHeNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cFIseyaR_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QgU0MFLs, 2, m, &cDelay_QgU0MFLs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KKjQ2eA0_sendMessage);
}

void Heavy_vSwellST::cMsg_G3s1ISG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_8LryHeNT, 0, m, &hTable_8LryHeNT_sendMessage);
}

void Heavy_vSwellST::cBinop_gGIQqQ0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_URa0IfaG_sendMessage);
}

void Heavy_vSwellST::cMsg_zY0ODnRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_8LryHeNT, 0, m, &hTable_8LryHeNT_sendMessage);
}

void Heavy_vSwellST::cCast_KKjQ2eA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QgU0MFLs, 0, m, &cDelay_QgU0MFLs_sendMessage);
}

void Heavy_vSwellST::cMsg_cFIseyaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_HBpy6owW, 2, m, &cDelay_HBpy6owW_sendMessage);
}

void Heavy_vSwellST::cMsg_LHEzXoRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_0toLXfpI, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_3TR4BgVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pzdhd4Y8, HV_BINOP_SUBTRACT, 0, m, &cBinop_Pzdhd4Y8_sendMessage);
}

void Heavy_vSwellST::cMsg_3lxzpY7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zVNOoZBz_sendMessage);
}

void Heavy_vSwellST::cSystem_zVNOoZBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_akf0ehoB_sendMessage);
}

void Heavy_vSwellST::cVar_nduK5Pqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8EKVJou9_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_L4hZXnwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_L4hZXnwF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_P5uyY4Rs, 0, m, &cDelay_P5uyY4Rs_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_d12ZHMpe, 0, m, &sTabread_d12ZHMpe_sendMessage);
}

void Heavy_vSwellST::cDelay_P5uyY4Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_P5uyY4Rs, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_d12ZHMpe, 0, m, &sTabread_d12ZHMpe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_P5uyY4Rs, 0, m, &cDelay_P5uyY4Rs_sendMessage);
}

void Heavy_vSwellST::sTabread_d12ZHMpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_MwCWOmEj, HV_BINOP_SUBTRACT, 0, m, &cBinop_MwCWOmEj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_nZjtGhjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q9PxQsR0, HV_BINOP_MAX, 0, m, &cBinop_q9PxQsR0_sendMessage);
}

void Heavy_vSwellST::cBinop_akf0ehoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nZjtGhjp, HV_BINOP_MULTIPLY, 0, m, &cBinop_nZjtGhjp_sendMessage);
}

void Heavy_vSwellST::cBinop_Pzdhd4Y8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zc54wUWY_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_d12ZHMpe, 0, m, &sTabread_d12ZHMpe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b2IzwT77_sendMessage);
}

void Heavy_vSwellST::cSystem_9SiBbF6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MwCWOmEj, HV_BINOP_SUBTRACT, 1, m, &cBinop_MwCWOmEj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_P5uyY4Rs, 2, m, &cDelay_P5uyY4Rs_sendMessage);
}

void Heavy_vSwellST::cMsg_8EKVJou9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9SiBbF6Y_sendMessage);
}

void Heavy_vSwellST::cMsg_Zc54wUWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_L4hZXnwF, 0, m, &cDelay_L4hZXnwF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_P5uyY4Rs, 0, m, &cDelay_P5uyY4Rs_sendMessage);
}

void Heavy_vSwellST::cMsg_QFbMoESu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_q9PxQsR0, HV_BINOP_MAX, 1, m, &cBinop_q9PxQsR0_sendMessage);
}

void Heavy_vSwellST::cBinop_q9PxQsR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pzdhd4Y8, HV_BINOP_SUBTRACT, 1, m, &cBinop_Pzdhd4Y8_sendMessage);
}

void Heavy_vSwellST::cCast_b2IzwT77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_L4hZXnwF, 0, m, &cDelay_L4hZXnwF_sendMessage);
}

void Heavy_vSwellST::cBinop_gxrWZpBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_L4hZXnwF, 2, m, &cDelay_L4hZXnwF_sendMessage);
}

void Heavy_vSwellST::cBinop_MwCWOmEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gxrWZpBx_sendMessage);
}

void Heavy_vSwellST::cCast_qRcOmvZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nduK5Pqr, 0, m, &cVar_nduK5Pqr_sendMessage);
  cMsg_3lxzpY7J_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3TR4BgVr, 0, m, &cTabhead_3TR4BgVr_sendMessage);
}

void Heavy_vSwellST::cUnop_vDTYzFvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zvzZpsvQ, m);
}

void Heavy_vSwellST::cCast_GJaMkxYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hncAhn6B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_9FXJc0KH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GJVrHL6J_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DsOForl5, 0, m, &cVar_DsOForl5_sendMessage);
}

void Heavy_vSwellST::cCast_X6zi8qKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ld6bzfP4, 0, m, &cVar_Ld6bzfP4_sendMessage);
}

void Heavy_vSwellST::cCast_xGSmUQ79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WeEWtGIt, HV_BINOP_SUBTRACT, 0, m, &cBinop_WeEWtGIt_sendMessage);
}

void Heavy_vSwellST::cBinop_WeEWtGIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GkEdu07u, 0, m, &cVar_GkEdu07u_sendMessage);
}

void Heavy_vSwellST::cSend_GJVrHL6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qCnKzMVu_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_253HqiY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qXcNfUBV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_rXLmZs0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_Mbdj5Tpm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_SKddBQPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GvNBBC7F, 0, m, NULL);
}

void Heavy_vSwellST::cSend_PTywbq9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aumLI9Hr_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_qLdaLQ3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_P2HSrcKf, 1, m, &cDelay_P2HSrcKf_sendMessage);
}

void Heavy_vSwellST::cBinop_LOwbTfcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_vDTYzFvL_sendMessage);
}

void Heavy_vSwellST::cReceive_l605ZcFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WeEWtGIt, HV_BINOP_SUBTRACT, 1, m, &cBinop_WeEWtGIt_sendMessage);
}

void Heavy_vSwellST::cReceive_vmhYgwKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8lTCvPdH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dGcAKYRA, 0, m, &cVar_dGcAKYRA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_S5DjZ7LF, 0, m, &cVar_S5DjZ7LF_sendMessage);
  cMsg_8whTkin8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_yUsDMSqy, 0, m, &cVar_yUsDMSqy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ftVVpmKO, 0, m, &cVar_ftVVpmKO_sendMessage);
  cMsg_P0kHd4LE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ydvEw7hk, 0, m, &cVar_ydvEw7hk_sendMessage);
  cMsg_A69Y9jyo_sendMessage(_c, 0, m);
  cMsg_ueswJ3h0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TDSeM11Z, 0, m, &cVar_TDSeM11Z_sendMessage);
  cMsg_t0yTNwRP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_byMp6y9Z, 0, m, &cVar_byMp6y9Z_sendMessage);
  cMsg_rL6TxPGd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IeSVGKoI, 0, m, &cTabhead_IeSVGKoI_sendMessage);
  cMsg_QFbMoESu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nduK5Pqr, 0, m, &cVar_nduK5Pqr_sendMessage);
  cMsg_3lxzpY7J_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3TR4BgVr, 0, m, &cTabhead_3TR4BgVr_sendMessage);
}

void Heavy_vSwellST::cReceive_kqoMHusN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_881SsyaW, 0, m, &cSlice_881SsyaW_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_60eUC78H, 0, m, &cSlice_60eUC78H_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_DpWXQmXR, 0, m, &cSlice_DpWXQmXR_sendMessage);
}

void Heavy_vSwellST::cReceive_5k5eanEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OnhVmdtd, m);
}

void Heavy_vSwellST::cReceive_qCnKzMVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JeJecZ1R_sendMessage(_c, 0, m);
  cMsg_bydyvYGH_sendMessage(_c, 0, m);
  cMsg_feVF1ZNb_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_7Hfx54UK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9FXJc0KH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GJaMkxYo_sendMessage);
}

void Heavy_vSwellST::cReceive_mitEVHYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GyRoetmD, 1, m, &cVar_GyRoetmD_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_JXzkq9MC, 1, m, &cPack_JXzkq9MC_sendMessage);
}

void Heavy_vSwellST::cReceive_O1AhwBwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_JXzkq9MC, 2, m, &cPack_JXzkq9MC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1gnBBkzI, 1, m, &cDelay_1gnBBkzI_sendMessage);
}

void Heavy_vSwellST::cReceive_FgI3tZE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_cqQ8rSYb, 1, m, &cPack_cqQ8rSYb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZQ8SMt0T, 1, m, &cVar_ZQ8SMt0T_sendMessage);
}

void Heavy_vSwellST::cReceive_CkGUprmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_cqQ8rSYb, 2, m, &cPack_cqQ8rSYb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3LstDT3N, 1, m, &cDelay_3LstDT3N_sendMessage);
}

void Heavy_vSwellST::cReceive_jHCgAO8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ljdwIdIJ, 2, m, &cPack_ljdwIdIJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fWVjpr0O, 1, m, &cDelay_fWVjpr0O_sendMessage);
}

void Heavy_vSwellST::cReceive_aumLI9Hr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TDSeM11Z, 1, m, &cVar_TDSeM11Z_sendMessage);
  cMsg_rXLmZs0P_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DsOForl5, 1, m, &cVar_DsOForl5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LyjpKlYA, 1, m, &cVar_LyjpKlYA_sendMessage);
}

void Heavy_vSwellST::cReceive_dOwXahEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PTywbq9B_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_AXYq3ieg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_qLdaLQ3h_sendMessage);
}

void Heavy_vSwellST::cReceive_FJySCXiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lVWFb5pn, m);
}

void Heavy_vSwellST::cReceive_NAkMMQyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lSoIt2mZ, m);
}

void Heavy_vSwellST::cReceive_dMLQns5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xGSmUQ79_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X6zi8qKT_sendMessage);
}

void Heavy_vSwellST::cReceive_1bTJVzSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LOwbTfcD_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1EDuTxTx, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwellST::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_hy9TJuS8, VIf(I0));
    __hv_tabwrite_f(&sTabwrite_0toLXfpI, VIf(I1));
    __hv_varread_f(&sVarf_lVWFb5pn, VOf(Bf0));
    __hv_varread_f(&sVarf_lSoIt2mZ, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_s2s9xTcN, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_M3Z4tAtc, VOf(Bf1));
    __hv_rpole_f(&sRPole_YqQ5ha2g, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_1EDuTxTx, VOf(Bf0));
    __hv_varread_f(&sVarf_zvzZpsvQ, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf2));
    __hv_gt_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_sqrt_f(VIf(Bf3), VOf(Bf3));
    __hv_and_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf2), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_nqlvq9FN, VIf(Bf2), &sEnv_nqlvq9FN_sendMessage);
    __hv_tabread_f(&sTabread_7kCKzuAo, VOf(Bf2));
    __hv_line_f(&sLine_GvNBBC7F, VOf(Bf0));
    __hv_varread_f(&sVarf_OnhVmdtd, VOf(Bf1));
    __hv_pow_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_6dsdIqoV, VOf(Bf0));
    __hv_max_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_tabread_f(&sTabread_d12ZHMpe, VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwellST::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwellST::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
