/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELLST_HPP_
#define _HEAVY_CONTEXT_VSWELLST_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalVar.h"
#include "HvControlTabhead.h"
#include "HvControlVar.h"
#include "HvControlIf.h"
#include "HvMath.h"
#include "HvSignalTabwrite.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"
#include "HvSignalDel1.h"
#include "HvControlSystem.h"
#include "HvTable.h"
#include "HvControlDelay.h"
#include "HvControlBinop.h"
#include "HvControlSlice.h"
#include "HvControlCast.h"
#include "HvControlPack.h"
#include "HvSignalEnvelope.h"
#include "HvSignalRPole.h"
#include "HvSignalTabread.h"

class Heavy_vSwellST : public HeavyContext {

 public:
  Heavy_vSwellST(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwellST();

  const char *getName() override { return "vSwellST"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_LEFT = 0x4E6E7C40, // Trigger_Left
        TRIGGER_RIGHT = 0xB181ABB6, // Trigger_Right
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_nqlvq9FN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_C6FfUjD4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4DGd3bLN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_ac52hSIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9koZ9BLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pdFZ28u9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oE6ncd19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9ebnCfA6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gpFarSej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qf2hLinY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3XsOj038_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ChdZ0aRA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_3MhVo779_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_PWfyJ12Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FMappCnp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_r5MNJvg8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hyLrSRL6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F0ufk5zl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IWE3l8ge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HUGcmdkt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fE1fetkH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_FFtip57j_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_6G64nXq6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HLi79mmi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9r1M817I_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_cXvV57co_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RltJ4yJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ld6bzfP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GkEdu07u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dqQPisdB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r4zmp1r9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VRcQxIW4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rpf0vwTk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_881SsyaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_60eUC78H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_DpWXQmXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_S5DjZ7LF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5VsSc7kx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_UgZMykTF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qKbDFiHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bGAu71On_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uIQTIFkM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_huKz1rQq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DWfLFmI8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cPazxhjj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oUMUysLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CAJd2ubI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qlvqjYQ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GPvl5jh5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tPbHRXKL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lKWmAFf5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X5wJgo0w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Nk49TqG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Cxsv7brM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_1gnBBkzI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_70zn9EEX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dTVhBCgK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_JXzkq9MC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LyjpKlYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JeJecZ1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RiMCR7js_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BfDSm7Km_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BCsVTyf1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rnsy0y6q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PdSPjrub_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_3LstDT3N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FU2gL818_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s9YFqObx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_cqQ8rSYb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GyRoetmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bydyvYGH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tHuGtW3B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8jSENLS5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0W7L1HJp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_64OdJIDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OvnwElXT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_fWVjpr0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kp1N3XT0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bqfuYeA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_ljdwIdIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZQ8SMt0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_feVF1ZNb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cvCRud9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XW8aKLkH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sg6HBWPP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kOx5uRkg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qXcNfUBV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_UdeqecdW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DsOForl5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TDSeM11Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8whTkin8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XtuAID0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xVRnJhz8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_gGgxtt1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lcbtdqhp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8lTCvPdH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dluaA8CX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dGcAKYRA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_125F00Pq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ENcFjRSU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4YLAayB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qLG4tkem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qSf5lowp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hmdWhTzy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_OtYlj9Yf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N1ItsnXU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Mbdj5Tpm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qns21Lat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_hzEsZduQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UfyAGMl2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ftVVpmKO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Y9ggSu8u_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_3POKzccF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yUsDMSqy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NW4kR9hh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pB9hsVrj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_yysuwTM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_23BkLja2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ecx9lexx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HtwUlMUs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nFwJHSqo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0xTikT6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_35bEzmD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VioxPyiH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hOqxs0KE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RO9Z36gh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xhytQYyu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jHQV4Y2y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LGAuQb3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GwWIkRw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SLHaXazG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kP3ba99c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rLS0t84a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TUqoeK6H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MBojWiek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5fcilwLL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YMJ2Z7Rq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gZxNhsiZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CZ8KGSwD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dpsAwBW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_trsuConz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gu5SNM82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nrpHSbaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kwz6T4D5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pJQRvcPg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WH8lE1uj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hncAhn6B_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_P2HSrcKf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6DZstFjA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1oHv8XUY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ydvEw7hk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P0kHd4LE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QLoGBq4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eoWSU6aL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZV8Hyzdx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aCWLGLSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M6HrrpUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mUJcx25p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T5ukpMfN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A69Y9jyo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sqX9SUNE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xSpkpq0m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_al949VxR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rfSnxNQn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_gePfmA0r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_VZzn4z2F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LqzQKMIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sJ7J0KI3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4qs31hft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DfSNWrmZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_45DsOuCn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nGwbJwzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_IeSVGKoI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rL6TxPGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GaTkC1yl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_byMp6y9Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xrhXAPWK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xMTK5cgP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_7kCKzuAo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R5cHqMcr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0X2hekze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uboKcJ7M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dTAfuG4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w6Gy8VrM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V5kVjNmi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t0yTNwRP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8zNhYo3S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C2CVdbwE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UzyhSwv9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8uQwmKgV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4gOXY6c7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ueswJ3h0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JTjqhyv7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QgU0MFLs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HBpy6owW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_G0cc0cN9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_URa0IfaG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_8LryHeNT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G3s1ISG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gGIQqQ0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zY0ODnRL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KKjQ2eA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cFIseyaR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LHEzXoRP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_3TR4BgVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3lxzpY7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zVNOoZBz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nduK5Pqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_L4hZXnwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_P5uyY4Rs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_d12ZHMpe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nZjtGhjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_akf0ehoB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pzdhd4Y8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9SiBbF6Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8EKVJou9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zc54wUWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QFbMoESu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q9PxQsR0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b2IzwT77_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gxrWZpBx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MwCWOmEj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qRcOmvZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vDTYzFvL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GJaMkxYo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9FXJc0KH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X6zi8qKT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xGSmUQ79_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WeEWtGIt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GJVrHL6J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_253HqiY9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rXLmZs0P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SKddBQPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_PTywbq9B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qLdaLQ3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LOwbTfcD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_l605ZcFa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vmhYgwKA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kqoMHusN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5k5eanEq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qCnKzMVu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7Hfx54UK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mitEVHYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_O1AhwBwc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FgI3tZE7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CkGUprmu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jHCgAO8e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aumLI9Hr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dOwXahEv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AXYq3ieg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FJySCXiO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NAkMMQyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dMLQns5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1bTJVzSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_hy9TJuS8;
  SignalTabwrite sTabwrite_0toLXfpI;
  SignalRPole sRPole_YqQ5ha2g;
  SignalEnvelope sEnv_nqlvq9FN;
  SignalTabread sTabread_7kCKzuAo;
  SignalLine sLine_GvNBBC7F;
  SignalTabread sTabread_d12ZHMpe;
  ControlSlice cSlice_4DGd3bLN;
  ControlSlice cSlice_ac52hSIW;
  ControlVar cVar_9koZ9BLq;
  ControlIf cIf_pdFZ28u9;
  ControlBinop cBinop_gpFarSej;
  ControlSlice cSlice_3MhVo779;
  ControlSlice cSlice_PWfyJ12Y;
  ControlVar cVar_FMappCnp;
  ControlIf cIf_r5MNJvg8;
  ControlBinop cBinop_IWE3l8ge;
  ControlVar cVar_Ld6bzfP4;
  ControlVar cVar_GkEdu07u;
  ControlBinop cBinop_dqQPisdB;
  ControlBinop cBinop_r4zmp1r9;
  ControlSlice cSlice_881SsyaW;
  ControlSlice cSlice_60eUC78H;
  ControlSlice cSlice_DpWXQmXR;
  ControlVar cVar_S5DjZ7LF;
  ControlIf cIf_qKbDFiHZ;
  ControlBinop cBinop_bGAu71On;
  ControlIf cIf_uIQTIFkM;
  ControlIf cIf_huKz1rQq;
  ControlIf cIf_DWfLFmI8;
  ControlIf cIf_cPazxhjj;
  ControlBinop cBinop_oUMUysLa;
  ControlBinop cBinop_CAJd2ubI;
  ControlBinop cBinop_qlvqjYQ9;
  ControlBinop cBinop_5Nk49TqG;
  ControlDelay cDelay_1gnBBkzI;
  ControlPack cPack_JXzkq9MC;
  ControlVar cVar_LyjpKlYA;
  ControlDelay cDelay_3LstDT3N;
  ControlPack cPack_cqQ8rSYb;
  ControlVar cVar_GyRoetmD;
  ControlDelay cDelay_fWVjpr0O;
  ControlPack cPack_ljdwIdIJ;
  ControlVar cVar_ZQ8SMt0T;
  ControlVar cVar_DsOForl5;
  ControlVar cVar_TDSeM11Z;
  SignalVarf sVarf_6dsdIqoV;
  ControlDelay cDelay_gGgxtt1J;
  ControlVar cVar_dGcAKYRA;
  ControlBinop cBinop_ENcFjRSU;
  ControlBinop cBinop_4YLAayB2;
  ControlBinop cBinop_qLG4tkem;
  ControlVar cVar_qSf5lowp;
  ControlSlice cSlice_qns21Lat;
  ControlSlice cSlice_hzEsZduQ;
  ControlVar cVar_UfyAGMl2;
  ControlVar cVar_ftVVpmKO;
  ControlVar cVar_yUsDMSqy;
  ControlVar cVar_NW4kR9hh;
  ControlVar cVar_pB9hsVrj;
  ControlSlice cSlice_yysuwTM6;
  ControlSlice cSlice_23BkLja2;
  ControlBinop cBinop_ecx9lexx;
  ControlBinop cBinop_HtwUlMUs;
  ControlBinop cBinop_nFwJHSqo;
  ControlBinop cBinop_0xTikT6I;
  ControlBinop cBinop_35bEzmD3;
  ControlBinop cBinop_RO9Z36gh;
  ControlBinop cBinop_xhytQYyu;
  ControlBinop cBinop_jHQV4Y2y;
  ControlBinop cBinop_LGAuQb3K;
  ControlBinop cBinop_5fcilwLL;
  ControlBinop cBinop_Gu5SNM82;
  ControlDelay cDelay_P2HSrcKf;
  ControlVar cVar_ydvEw7hk;
  ControlBinop cBinop_eoWSU6aL;
  ControlBinop cBinop_ZV8Hyzdx;
  SignalVarf sVarf_M3Z4tAtc;
  ControlBinop cBinop_M6HrrpUi;
  ControlBinop cBinop_mUJcx25p;
  ControlBinop cBinop_T5ukpMfN;
  SignalVarf sVarf_s2s9xTcN;
  ControlDelay cDelay_xSpkpq0m;
  ControlDelay cDelay_al949VxR;
  ControlBinop cBinop_gePfmA0r;
  HvTable hTable_VZzn4z2F;
  ControlBinop cBinop_sJ7J0KI3;
  ControlTabhead cTabhead_IeSVGKoI;
  ControlVar cVar_byMp6y9Z;
  ControlDelay cDelay_xrhXAPWK;
  ControlDelay cDelay_xMTK5cgP;
  ControlBinop cBinop_R5cHqMcr;
  ControlBinop cBinop_0X2hekze;
  ControlBinop cBinop_uboKcJ7M;
  ControlBinop cBinop_8zNhYo3S;
  ControlBinop cBinop_UzyhSwv9;
  ControlBinop cBinop_8uQwmKgV;
  ControlDelay cDelay_QgU0MFLs;
  ControlDelay cDelay_HBpy6owW;
  ControlBinop cBinop_URa0IfaG;
  HvTable hTable_8LryHeNT;
  ControlBinop cBinop_gGIQqQ0i;
  ControlTabhead cTabhead_3TR4BgVr;
  ControlVar cVar_nduK5Pqr;
  ControlDelay cDelay_L4hZXnwF;
  ControlDelay cDelay_P5uyY4Rs;
  ControlBinop cBinop_nZjtGhjp;
  ControlBinop cBinop_akf0ehoB;
  ControlBinop cBinop_Pzdhd4Y8;
  ControlBinop cBinop_q9PxQsR0;
  ControlBinop cBinop_gxrWZpBx;
  ControlBinop cBinop_MwCWOmEj;
  ControlBinop cBinop_WeEWtGIt;
  ControlBinop cBinop_253HqiY9;
  ControlBinop cBinop_qLdaLQ3h;
  ControlBinop cBinop_LOwbTfcD;
  SignalVarf sVarf_OnhVmdtd;
  SignalVarf sVarf_lVWFb5pn;
  SignalVarf sVarf_lSoIt2mZ;
  SignalVarf sVarf_zvzZpsvQ;
  SignalVarf sVarf_1EDuTxTx;
};

#endif // _HEAVY_CONTEXT_VSWELLST_HPP_
